# coding: utf-8

#   TypeAtlas Collection of International Sample Texts: Pangrams and others
#       Collected 2018 by Milko Krachounov,
#       Sources copyrighted by various third parties attributed below
#              (Wikipedia contributors, Wikiquote contributors, StackExchange
#               contributors, etc.)
#
#   Part of TypeAtlas. TypeAtlas is free software.
#
#    If deemed copyrightable, and minding the license of the sources,
#    TypeAtlas Collection of International Sample Texts are licensed under a
#    Creative Commons Attribution-ShareAlike 3.0 Unported License.
#
#    They are distributed without any warranty.
#
#    You should have received a copy of the license along with this
#    work.  If not, see <http://creativecommons.org/licenses/by-sa/3.0/>.

# The language samples here are phrases compiled from various sources.
# While phrases themselves may not fall under copyright, certain sources
# were cited often enough to make this potentially a derivative work
# (of the Wikipedia List of Pangrams, mostly).
#
# Just to be safe:
#   1) Samples are split into files based on whether they were collected
#      from CC-BY-SA licensed sources (samples_language.py), LGPL licensed
#      sources (samples_language_pango.py), or sources with less clear
#      licensing (samples_language_glass.py). (Suspected non-free files
#      in samples_language_nonfree.py, if included with your distribution)
#   2) This notice lists ll the sources, the copyright, and their license.
#   3) This notice adds additional permissions and clarifications
#      pertaining to this collection, if seen as a collective derivative work,
#      and all additional contributions are quintuple-licensed under GPL 3,
#      LGPL 2, MIT/X11, CC-BY-SA 3.0 and CC-BY-SA 4.0 (just to be on the safe
#      side). (If this is too restrictive, I can be persuaded to grant more).
#   4) Each sample individually cites its own sources.
#
###########################################################################
#
#   2) Sources, their copyright and licenses:
#      ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
# These sample texts are acquired from multiple sources. While the sources
# are not generally copied in substantial form, the copyright and license to
# these sources is cited here. These include:
#
#  * Wikipedia pages, written and compiled by their Wikipedia contributors.
#       - "List of Pangrams." Since deleted from Wikipedia, mirrored by:
#            + archive.org
#            + clagnut.com
#            + thefullwiki.org
#       - "Sample Font Displays In Other Languages." Deleted, mirrored by:
#            + archive.org
#            + thefullwiki.org
#       - Various translations of the "Pangram" article, listed below
#       - Various international Wikipedia pages listed below
#     The Wikipedia articles are Copyrighted (C) by the Wikipedia Contributors.
#     Their text is available under the
#       Creative Commons Attribution-ShareAlike 3.0 License (CC BY-SA 3.0).
#
#  * Wikiquote Pages. Wikiquote pages are Copyrighted (C) by the Wikiquote
#    contributors to the page. Their text is available under the
#    Creative Commons Attribution-ShareAlike 3.0 License (CC BY-SA 3.0).
#
#  * Various StackExchange pages, written Copyrighted (C) by their respective
#    contributors. User contributions are available under the
#       Creative Commons Attribution-ShareAlike 3.0 License (CC BY-SA 3.0).
#
#  * Pango Language Sample Table (pango-language-sample-table.h)
#     Written, collected, and Copyrighted (C) by Pango developers, and all those
#     who contributed phrases in bug reports and others, and/or their sources.
#
#     Most of the code of Pango is licensed under the terms of the
#     GNU Lesser Public License (LGPL). (aka Library GPL; Most files are
#     Version 2 or later, but the language sample table doesn't carry explicit
#     notice, however we didn't copy the table itself, so it's not clear that
#     its copyright notice has any direct relevance to copying this file)
#
#     No phrases in this file are taken exclusively from Pango. Those are in a separate
#     file. Only included here are phrases that Pango seems to have sourced from
#     the same source as we do, or at least are also included in a CC-BY-SA 3.0
#     source.
#
#  * Font Testing Page by Pablo Impallari (copyright dates may be wrong)
#       Copyright (c) 2011-2017 Pablo Impallari
#       Copyright (c) 2011-2013 Pablo Cosgaya
#       Copyright (c) 2011-2013 Dave Crossland
#       Copyright (c) 2011-2013 James Montalbano
#       Copyright (c) 2011-2013 Eduardo Tunni
#       Copyright (c) 2011-2013 Wikipedia contributors, 'List of pangrams' page
#     Code is available under the MIT License, see LICENSE.md for full details
#     Page text is available under the Creative Commons
#     Attribution-ShareAlike v3.0 License
#
#  * The Bulgarian sample I took from a magazine, but then I found it
#    in the sources above, so the publisher should forgive me I don't
#    recall which magazine it was. (Or rather I found the sources above by
#    searching for the sample.)
#
############################################################################
#
#   3) TypeAtlas Collection of International Sample Texts, Copyright and
#      License
#      ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#    For any contributions, such as additions and modifications made for TypeAtlas,
#    that resulted in this sample phrase selection and sample text collection,
#    including all the collective work, phrase curation, and the support "source
#    code" that defines the sample data in the sample files (that is,
#    data/samples_language.py, data/samples_language_pango.py and
#    data/samples_language_glass.py; this notice applies to three files,
#    I will not copy it there)
#
#    This includes anything deemed copyrightable that has been contributed, whether
#    it pertains to creating a collective work of collected phrases, any added
#    translations, or transliterations, and any part of this data file that for some
#    reason can be mistaken for software, even elements of the work the author may not
#    view as copyrightable, but wishes to provide with explicit permissions
#    under the following licenses:
#
#    Copyright (C) 2018-2021 Milko Krachounov
#
#    Any contributions by Milko Krachounov to this work (Collection of
#    International Sample Texts) are licensed under a Creative Commons
#    Attribution 3.0 Unported License.
#
#    You should have received a copy of the license along with this
#    work.  If not, see <http://creativecommons.org/licenses/by/3.0/>.
#
#                                 ***
#
#    Alternatively, any contributions by Milko Krachounov to this work (Collection
#    of International Sample Texts) are licensed under a Creative Commons
#    Attribution 4.0 International License.
#
#    You should have received a copy of the license along with this
#    work.  If not, see <http://creativecommons.org/licenses/by/4.0/>.
#
#                                 ***
#
#    Alternatively, Milko Krachounov grants you permission to redistribute
#    and/or modify his contributions to this work under the terms of the GNU
#    General Public License as published by the Free Software Foundation,
#    either version 3 of the License, or (at your option) any later version.
#
#    TypeAtlas is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with TypeAtlas.  If not, see <http://www.gnu.org/licenses/>.
#
#                                 ***
#
#    Alternatively, Milko Krachounov grants you permission to redistribute
#    and/or modify his contributions to this work under the terms of
#    the GNU Library General Public License as published by the Free
#    Software Foundation; either version 2 of the License, or (at your
#    option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.> See the GNU
#    Library General Public License for more details.
#
#    You should have received a copy of the GNU Library General Public
#    License along with this library; if not, write to the
#    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
#    Boston, MA 02111-1307, USA.
#
#                                 ***
#
#    Alternatively,
#
#    Permission is hereby granted, free of charge, to any person obtaining a
#    copy of any contributions by Milko Krachounov to this work, Collection of
#    Sample Text, (the "Software"), to deal in the Software without
#    restriction, including without limitation the rights to use,
#    copy, modify, merge, publish, distribute, sublicense, and/or sell
#    copies of the Software, and to permit persons to whom the
#    Software is furnished to do so, subject to the following
#    conditions:
#
#    The above copyright notice and this permission notice shall be
#    included in all copies or substantial portions of the Software.
#
#    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
#    OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
#    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
#    HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
#    WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
#    OTHER DEALINGS IN THE SOFTWARE.
#

# ^^^^^^^^
# This file contains data, and *NO* (copyrightable) software, so compatibility
# with GPL is not required to use this data, but I explicitly grant permissions
# to copy "the software" under the GPL, should anyone mistakenly decide there
# is code in this file in any form (or like rules it linked with TypeAtlas or
# smth)


# The English "translations" in thee documents are tentative and very rough,
# intended to hint at the general subject matter of the phrases (some of
# which may be almost-nonsensical, or untranslatable). DO NOT assume they are
# correct, or even representative, translations.
#
# These English texts are included with the samples so that anyone inspecting
# the document has a clue as to the general wording of the sample text, such as
# general assurance they don't insult the reader too much, they don't
# openly promote the ingestion of popular detergents brands or riding
# bicycles without a helmet.
#
# No warranties are made. Some phrases may promote controversial subjects like
# electricity, anthropomorphic fruits, animals playing musical instruments, or
# casually mention alcoholic beverages. Others may even make wild claims of
# people ingesting molten silica without internal disarray or requirement of
# patient care. These people are probably Moclans, not humans.


from __future__ import unicode_literals
from typeatlas.samples import add_sample, use_fallback, use_display_scripts
from typeatlas.samples import PHRASE, PANGRAM, PANGRAM_PARTIAL_ACCENTS
from typeatlas.samples import PANGRAM_LIMITED_ACCENTS, PARTIAL_PANGRAM, PERFECT_PANGRAM
from typeatlas.samples import KOREAN_PANGRAM, KOREAN_CONSONANT_PANGRAM
from typeatlas.samples import YONG_CHARACTER, SYLLABLE_PANGRAM
from typeatlas.samples import PRIO_PREFER, PRIO_WITHHOLD


# Need: gn, dak, mi

# Sources, origins, and users of the phrases.

PANGO = 'Pango Language Sample Table'
GNOME = 'GNOME'

WP_PAN_EN = 'Pangram - Wikipedia, 23:33, 15 May 2018 <https://en.wikipedia.org/w/index.php?title=Pangram&oldid=841455362>'
WP_PAN_DE = 'Pangramm - Wikipedia, 2. November 2017 um 16:04 <https://de.wikipedia.org/w/index.php?title=Pangramm&oldid=170578983>'
WP_PAN_AR = 'جامع حروف - ويكيبيديا، الموسوعة الحرة, 17:02، 30 نوفمبر 2017 <https://ar.wikipedia.org/w/index.php?title=%D8%AC%D8%A7%D9%85%D8%B9_%D8%AD%D8%B1%D9%88%D9%81&oldid=25730743>'
WP_PAN_ES = 'Pangrama - Wikipedia, la enciclopedia libre, 16:45 5 abr 2018 <https://es.wikipedia.org/w/index.php?title=Pangrama&oldid=106733458>'
WP_PAN_UK = 'Панграма — Вікіпедія, 19:21, 27 серпня 2017 <https://uk.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%B0&oldid=20953448>'
WP_PAN_RU = 'Панграмма — Википедия, 14:39, 13 апреля 2018 <https://ru.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%B0&oldid=92068074>'
WP_PAN_TH = 'แพนแกรม - วิกิพีเดีย, 02:33, 8 พฤศจิกายน 2560 <https://th.wikipedia.org/w/index.php?title=%E0%B9%81%E0%B8%9E%E0%B8%99%E0%B9%81%E0%B8%81%E0%B8%A3%E0%B8%A1&oldid=7297883>'
WP_PAN_KO = 'The quick brown fox jumps over the lazy dog - 위키백과, 우리 모두의 백과사전, 2018년 1월 27일 (토) 14:50 판 <https://ko.wikipedia.org/w/index.php?title=The_quick_brown_fox_jumps_over_the_lazy_dog&oldid=20572829>'
WP_PAN_TR = 'Pangram - Vikipedi, 14.54, 12 Ocak 2017 <https://tr.wikipedia.org/w/index.php?title=Pangram&oldid=18038786>'
WP_PAN_HE = 'פנגרמה – ויקיפדיה, 08.06.18, בשעה 09:00. <https://he.wikipedia.org/w/index.php?title=%D7%A4%D7%A0%D7%92%D7%A8%D7%9E%D7%94&oldid=20163492>'
WP_PAN_EL = 'Παντόγραμμα - Βικιπαίδεια, 18:57, 1 Απριλίου 2018 <https://el.wikipedia.org/w/index.php?title=%CE%A0%CE%B1%CE%BD%CF%84%CF%8C%CE%B3%CF%81%CE%B1%CE%BC%CE%BC%CE%B1&oldid=6971942>'

WP_PAN_SR = 'Панграм — Википедија, слободна енциклопедија, 12:26, 20. март 2017 <https://sr.wikipedia.org/w/index.php?title=%D0%9F%D0%B0%D0%BD%D0%B3%D1%80%D0%B0%D0%BC&oldid=12459258>'
WP_PAN_HR = 'Pangram – Wikipedija, 30. listopada 2015. u 13:03 <https://hr.wikipedia.org/w/index.php?title=Pangram&oldid=4613487>'
WP_PAN_FA = 'پانگرام - ویکی‌پدیا، دانشنامهٔ آزاد،  ‏۲۵ سپتامبر ۲۰۱۷، ساعت ۱۱:۲۴ <https://fa.wikipedia.org/w/index.php?title=%D9%BE%D8%A7%D9%86%DA%AF%D8%B1%D8%A7%D9%85&oldid=21278386>'
WP_PAN_SL = 'Pangram - Wikipedija, prosta enciklopedija, 10:50, 13. julij 2017 <https://sl.wikipedia.org/w/index.php?title=Pangram&oldid=4876880>'
WP_PAN_FR = 'Pangramme — Wikipédia, 22 décembre 2017 à 10:48 <https://fr.wikipedia.org/w/index.php?title=Pangramme&oldid=143746074>'
WP_PAN_HU = 'Pangramma - Wikipédia, 2017. február 17., 16:41 <https://hu.wikipedia.org/w/index.php?title=Pangramma&oldid=18451372>'
WP_PAN_FI = 'Pangrammi - Wikipedia, 15. huhtikuuta 2018 kello 12.35 <https://fi.wikipedia.org/w/index.php?title=Pangrammi&oldid=17239063>'


WP_IROHA = 'Iroha - Wikipedia, 06:04, 8 May 2018 <https://en.wikipedia.org/w/index.php?title=Iroha&oldid=840175871>'
WP_THOUSAND_CHARACTER = 'Thousand Character Classic - Wikipedia, 13:51, 20 May 2018 <https://en.wikipedia.org/w/index.php?title=Thousand_Character_Classic&oldid=842138167>'

WP_SAMPLES = 'Sample Font Displays In Other Languages, Wikipedia, The Full Wiki Mirror <http://www.thefullwiki.org/Sample_Font_Displays_In_Other_Languages>'
WP_PANGRAMS_ARCHIVE_2014 = 'List of Pangrams, Wikipedia, 12 October 2014 <https://web.archive.org/web/20141012231620/http://en.wikipedia.org/wiki/List_of_pangrams>'
WP_PANGRAMS_ARCHIVE_2014_SEP = 'List of Pangrams, Wikipedia, 8 September 2014 <https://web.archive.org/web/20140908073444/http://en.wikipedia.org/wiki/List_of_pangrams>'
WP_PANGRAMS_ARCHIVE_2010 = 'List of Pangrams, Wikipedia, 23 February 2010 <https://web.archive.org/web/20100223134506/http://en.wikipedia.org/wiki/List_of_pangrams>'

WP_PANGRAMS_MIRROR_2010 = 'List of Pangrams, Wikipedia, The Full Wiki mirror, 19 August 2010 <https://www.thefullwiki.org/List_of_pangrams>'
WP_PANGRAMS_MIRROR_2014 = 'List of Pangrams, Wikipedia, Richard Rutter mirror, 30 October 2014 <http://clagnut.com/blog/2380/>'


FONTEST_IMPALLARI = 'Font Testing Page by impallari, 8 May 2017 <https://github.com/impallari/Font-Testing-Page/tree/21a03e251623764771ada80b98036d3cd04bc294>'

PANGRAM_CONTEST_PZABAV = "Pangram contest by “Politikin Zabavnik”"
PANGRAM_CONTEST_PZABAV_1984 = "“Rečenicu od najmanje slova” (“Sentences of all letters”) contest, 1984, “Politikin Zabavnik”"


add_sample('en',
           #'The quick brown fox jumps over the lazy dog.',
           'The quick brown fox jumps over the sleazy iffy dog.',
           origin='The Boston Journal', type=PANGRAM, script='Latn')

add_sample('en',
           'Jackdaws love my big sphinx of quartz.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           flags=['redmond'])

add_sample('en',
           'How vexingly quick daft zebras jump!',
           sources=[WP_PAN_EN], type=PANGRAM, script='Latn')

add_sample('en',
           'This pangram contains four As, one B, two Cs, one D, thirty Es, six Fs, five Gs, seven Hs, eleven Is, one J, one K, two Ls, two Ms, eighteen Ns, fifteen Os, two Ps, one Q, five Rs, twenty-seven Ss, eighteen Ts, two Us, seven Vs, eight Ws, two Xs, three Ys, & one Z.',
           sources=[WP_PAN_EN], type=PANGRAM, script='Latn', prio=PRIO_WITHHOLD)

add_sample('bg',
           'За миг бях в чужд, скърцащ плюшен фотьойл.',
           origin='Macintosh System 7',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Cyrl',
           english="For a moment I was in another's, creaking plush armchair.",
           translit='Za mig byah v chuzhd, skurtsasht plyushen fotjyoyl.',
           flags=['old-mac'])

add_sample('bg',
           'Под южно дърво, цъфтящо в синьо, бягаше малко пухкаво зайче.',
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Cyrl',
           english="Under a southern tree, blooming in blue, a little fluffy rabbit was running.",
           translit='Pod yuzhno darvo, tsaftyashto v sinyo, byagashe malko puhkavo zayche.')

add_sample('bg',
           'Жълтата дюля беше щастлива, че пухът, който цъфна, замръзна като гьон.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Cyrl',
           english='The yellow quince was happy that the fluff which bloomed froze like sole-leather.',
           translit='Zhaltata dyula beshe shtastliva, che puhat, koyto tsafna, zamrazna kato gyon.')

add_sample('de',
           'Zwölf Boxkämpfer jagen Viktor quer über den großen Sylter Deich.',
           sources=[WP_PAN_DE, PANGO], type=PANGRAM, script='Latn',
           english='Twelve boxers chase Viktor over the great dam of Sylt.')

add_sample('de',
           'Falsches Üben von Xylophonmusik quält jeden größeren Zwerg.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english='Wrong practising of xylophone music bothers every larger dwarf.')

add_sample('de',
           '„Fix, Schwyz!„ quäkt Jürgen blöd vom Paß.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english='“Quick, Schwyz!” Jürgen squawks zanily from the pass.')

## Removed from Wikipedia's page? It is a pangram, but may be gibberish?
#add_sample('de', 'Züchtigsüß rät Quasidame bösem Pony: „Wirf Klavier zum Jux“.',
#           origin='', sources=[WP_PAN_DE])

add_sample('ar', 'نص حكيم له سر قاطع وذو شأن عظيم مكتوب على ثوب أخضر ومغلف بجلد أزرق',
           sources=[WP_PAN_AR, PANGO], type=PANGRAM, script='Arab',
           english='A wise text with a definite secret and great significance, written on green cloth and wrapped in blue leather.',
           translit='naṣun ḥakymun lahu syrun qāṭiʿun wa ḏu šānin ʿẓymin maktubun ʿala ṯubin aẖḍra wa muġalafun biǧildin azraq')


add_sample('ar', 'اصبر على حفظ خضر واستشر فطنا، وزج همك في بغداذ منثملا',
           sources=[WP_PAN_AR, WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Arab',
           english='Be careful to protect the grasses and consult the clever, and put your concerns in a great effort',
           translit='asbir ealaa hifz khadir waistashara fatnaan, wazaja humk fi bighidadh munathmalaan',
           flags=['translation-wrong'])

add_sample('ar', 'هلا سكنت بذي ضغثٍ فقد زعموا — شخصت تطلب ظبياً راح مجتازا',
           sources=[WP_PAN_AR, WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Arab',
           # Have no idea what this means.
           # Most pangrams *are* gibberish, so I guess some are untranslatable.
           # Tried online translators, and they gave me, paraphrasing:
           # “She was taken aback, she claimed she was asked to ask a boy passing her by.”
           # “...she claimed she asked for a bird called in passing”
           # “...she claimed a person who asked for a bird went away”
           # But ‘ظبياً’ is an antelope. So improvising:
           english='Hala calmed down after getting lost - she claimed she proceeded to ask an antelope passing by.',
           translit='hla sakanat badhi dghth faqad zaeamuu - shakhasat tatlub zbyaan rahan mujtazana',
           flags=['translation-wrong'])

add_sample('fa', 'بر اثر چنین تلقین و شستشوی مغزی جامعی، سطح و پایهٔ ذهن و فهم و نظر بعضی اشخاص واژگونه و معکوس می‌شود',
           sources=[WP_PAN_FA], type=PANGRAM, script='Arab',
           english='As a result of such indoctrination and brainwashing, the foundation of the mind and the understanding of some people are inverted.',
           translit="'ber ather chenan telqan w shesteshewa megheza jam'ea, seth w peaah dhen w fhem w nezr b'eda ashekhas wajeguwenh w m'ekewes ma‌shewd'")

add_sample('es',
           'Jovencillo emponzoñado de whisky: ¡qué figurota exhibe!',
           sources=[WP_PAN_ES, PANGO], type=PANGRAM, script='Latn',
           english="Youngster drunk on whiskey — what a figure he's exhibiting!.")

add_sample('es',
           'Benjamín pidió una bebida de kiwi y fresa. Noé, sin vergüenza, la más exquisita champaña del menú.',
           sources=[WP_PAN_ES], type=PANGRAM, script='Latn',
           english='Benjamin asked for a kiwi and strawberry. Noah, without shame, the most exquisite champagne on the menu.')

add_sample('es',
           'El veloz murciélago hindú comía feliz cardillo y kiwi. La cigüeña tocaba el saxofón detrás del palenque de paja.',
           sources=[WP_PANGRAMS_ARCHIVE_2014, WP_PAN_ES], type=PANGRAM, script='Latn',
           english='The quick Hindu bat was happily eating golden thistle and kiwi. The stork was playing the saxophone behind the straw arena.',
           flags=['redmond'])


add_sample('uk',
           "Щастям б'єш жук їх глицю в фон й ґедзь пріч.",
           sources=[WP_PAN_UK], type=PANGRAM, script='Cyrl',
           english='Happily you hit the beetle in their needles in the background and the horsefly is gone.',
           translit="Shchastjam b'yesh zhuk yikh hlytsju v fon j gedz' prich.",
           origin='Віктор Олексенко (Viktor Oleksenko)')

add_sample('uk',
           'Чуєш їх, доцю, га? Кумедна ж ти, прощайся без ґольфів!',
           sources=[WP_PAN_UK, PANGO], type=PANGRAM, script='Cyrl',
           english='Daughter, do you hear them, eh? Oh, you are funny! Say good-bye without knee-length socks.',
           translit="Chuyesh yikh, dotsju, ha? Kumedna zh ty, proshchajsja bez gol'fiv!")

add_sample('uk',
           'Жебракують філософи при ґанку церкви в Гадячі, ще й шатро їхнє знаємо.',
           sources=[WP_PAN_UK, WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Cyrl',
           origin='Ярослав Кохан (Ярослав Кохан)',
           english='The philosophers beg near the porch of the church in Hadiach, and we even know their drunk tent.',
           translit="Zhebrakujut' filosofy pry ganku tserkvy v Hadjachi, shche j shatro yikhnye znayemo.")

add_sample('ru',
           'В чащах юга жил бы цитрус? Да, но фальшивый экземпляр!',
           sources=[WP_PAN_RU, PANGO], type=PANGRAM, script='Cyrl',
           english='Would a citrus fruit live in the thickets of the south? Yes, but a fake one!',
           translit="V chaschah juga zhil by tsitrus? Da, no fal'shivyj ekzempljar!")

add_sample('ru',
           'Широкая электрификация южных губерний даст мощный толчок подъёму сельского хозяйства.',
           sources=[WP_PAN_RU, WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Cyrl',
           english='Widespread electrification of the Southern provinces will give a powerful push to the rise of agriculture.',
           translit='''Shirokaja elektrifikatsija juzhnyh gubernij dast moschnyj tolchok pod"jomu sel'skogo hozjajstva.''',
           flags=['kde'])

add_sample('ru',
           'Съешь же ещё этих мягких французских булок, да выпей чаю!',
           sources=[WP_PAN_RU, WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Cyrl',
           english='So eat more of these soft French loaves, and have some tea!',
           translit='''S"esh' zhe eschjo etih mjagkih frantsuzskih bulok, da vypej chaju!''',
           flags=['redmond'])

add_sample('tr',
           'Pijamalı hasta yağız şoföre çabucak güvendi',
           sources=[WP_PAN_TR, PANGO], type=PANGRAM, script='Latn',
           english='The patient in pajamas trusted the swarthy driver quickly')

add_sample('ko',
           '키스의 고유조건은 입술끼리 만나야 하고 특별한 기술은 필요치 않다',
           sources=[GNOME, WP_PAN_KO], type=KOREAN_PANGRAM, script='Hang',
           english='The unique condition of the kiss is that the lips must meet and no special skills are needed',
           translit='goyujogeoneun ipsulkkiri mannaya hago teukbyeolhan gisureun pilyochi antha')

add_sample('ko',
           '정 참판 양반댁 규수 큰 교자 타고 혼례 치른 날',
           sources=[WP_PAN_KO, 'google'], type=KOREAN_PANGRAM, script='Hang',
           english='On the day when a marriage ceremony was held with a large jiaozi',
           translit='jeong champan yangbandaeg gyusu keun gyoja tago honlye chileun nal',
           flags=['google'])

add_sample('ko',
           "다람쥐 헌 쳇바퀴에 타고파",
           sources=[PANGO, WP_SAMPLES],
           type=KOREAN_CONSONANT_PANGRAM, script='Hang',
           english="I wanna ride on the chipmunk's old hamster wheel.")

add_sample('th',
           'เป็นมนุษย์สุดประเสริฐเลิศคุณค่า - กว่าบรรดาฝูงสัตว์เดรัจฉาน - จงฝ่าฟันพัฒนาวิชาการ อย่าล้างผลาญฤๅเข่นฆ่าบีฑาใคร - ไม่ถือโทษโกรธแช่งซัดฮึดฮัดด่า - หัดอภัยเหมือนกีฬาอัชฌาสัย - ปฏิบัติประพฤติกฎกำหนดใจ - พูดจาให้จ๊ะๆ จ๋า น่าฟังเอยฯ',
           sources=[WP_PAN_TH, PANGO], type=PANGRAM, script='Thai',
           english='Being a man is worthy - Beyond senseless animal - Begin educate thyself - Begone from killing and trouble - Bear not thy grudge, damn and, curse - Bestow forgiving and sporting - Befit with rules - Benign speech speak thou')

add_sample('he', 'עטלף אבק נס דרך מזגן שהתפוצץ כי חם.',
           sources=[WP_PAN_HE], type=PANGRAM, script='Hebr',
           english="A dust bat ran away through an air conditioner which exploded because it's hot",
           translit='Tlf vk ns drch mzgn shhtfvtztz ch chm')

add_sample('he', 'דג סקרן שט בים מאוכזב ולפתע מצא חברה.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Hebr',
           translit='Dg skrn sht vm mvchzv vlft mtz chvrh',
           english='A curious fish sailed the sea disappointedly, and suddenly found company')

add_sample('he', 'מנעולן הפך כף חצץ שגזר קט איבד סתם.',
           sources=[WP_PAN_HE], type=PANGRAM, script='Hebr',
           english='A locksmith turned a tablespoon of gravel that a small fragment had just lost.',
           translit="Mn'vln hfch chf chtztz shgzr kt vd stm",
           flags=['translation-wrong'])

add_sample('he', 'איך נטוס עם גד כץ, הזקן שמֻחלף בצרפת?',
           sources=[WP_PAN_HE], type=PANGRAM, script='Hebr',
           english='How will we fly with Gad Katz, the old man who is replaced in France?',
           translit='Ch ntvs m gd chtz, hzkn shmuchlf vtzrft?',
           flags=['translation-wrong'])

# Slightly different than the second one. The number and kind of people in
# the company changed, and suddenly got three words longer?
add_sample('he',  "דג סקרן שט לו בים זך אך לפתע פגש חבורה נחמדה שצצה כך.",
           sources=[PANGO, WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Hebr',
           english='A curious fish sailed the sea disappointedly, and suddenly found company',
           translit='Dg skrn sht lv vm zch ch lft fgsh chvvrh nchmdh shtztzh chch.')


add_sample('el',
           'Ξεσκεπάζω την ψυχοφθόρα βδελυγμία.',
           sources=[WP_PAN_EL], type=PANGRAM, script='Grek',
           english='I unravel the soul-destroying abomination',
           translit="Xeskepazo tin psuchofthora vdelugmia.")
add_sample('el',
           'Θέλει αρετή και τόλμη η ελευθερία. (Ανδρέας Κάλβος)',
           sources=[PANGO, WP_PANGRAMS_ARCHIVE_2014],
           type=PHRASE, script='Grek',
           english='Liberty requires virtue and mettle. (Andreas Kalvos)',
           translit="Thelei areti kai tolmi i eleutheria. (Andreas Kalvos)")


use_display_scripts('sr', ['Cyrl', 'Latn'])
use_display_scripts('bs', ['Latn', 'Cyrl'])
use_fallback('hr', 'sr', script='Latn')
use_fallback('sr', 'hr', script='Latn')
use_fallback('bs', 'sr')

# fontconfig returns 'sr' when Cyrillic is supported, and 'hr' when Latin is
# that kind of works, but we could do better, in particular display a
# the hybrid phrase for Serbian locales, perhaps by interpretation of the
# display scripts
add_sample('sr',
           'Фијуче ветар у шибљу, леди пасаже и куће иза њих и гунђа у оџацима.',
           script='Cyrl', sources=[WP_PAN_SR], type=PANGRAM,
           origin=PANGRAM_CONTEST_PZABAV_1984,
           english="Wind whistles in the bushes, the ice passages and the houses behind them, and grumbles in the chimneys.",
           translit='Fijuče vetar u šiblju, ledi pasaže i kuće iza njih i gunđa u odžacima.',
           note="Won first place")

add_sample('sr',
           'Вук Његошу: „Не ломи џабе перо, дођи тићу, чије се фаце зажељех”.',
           script='Cyrl', sources=[WP_PAN_SR], type=PANGRAM,
           origin=PANGRAM_CONTEST_PZABAV_1984,
           english='Vuk Njegošu: "Do not break the free feather, coming, whose face I desired".',
           translit='Vuk Njegošu: „Ne lomi džabe pero, dođi tiću, čije se face zaželjeh”.',
           note="Won second place", flags=['translation-wrong'])

add_sample('sr',
           'Ниџо, чежњиво гледаш фотељу, а Ђура и Мика хоће позицију себи.',
           script='Cyrl', sources=[WP_PAN_SR], type=PANGRAM,
           origin=PANGRAM_CONTEST_PZABAV_1984,
           english="Nidžo, looking at the couch with sadness, while Đura and Mika want a position for themselves.",
           translit='Nidžo, čežnjivo gledaš fotelju, a Đura i Mika hoće poziciju sebi.',
           note="Won third place")

add_sample('sr',
           'Njoj pljačkom zgrćeš tuđ CD, VHS, bež fildžan.',
           script='Latn',
           sources=[WP_PAN_SR], type=PANGRAM,
           english="You rob someone else's CD, VHS, beige coffee cup.")

_SR_HYBRID_LATIN = "Češće ceđenje mrežastim džakom poboljšava fertilizaciju genskih hibrida."
_SR_HYBRID_ENGLISH = 'More frequent filtering through the reticular bag improves fertilization of genetic hybrids.'

add_sample('sr',
           "Чешће цeђење мрeжастим џаком побољшава фертилизацију генских хибрида.",
           script='Cyrl', sources=[PANGO, WP_SAMPLES],
           translit=_SR_HYBRID_LATIN,
           english=_SR_HYBRID_ENGLISH)

add_sample('sr', _SR_HYBRID_LATIN,
           script='Latn', sources=[PANGO, WP_SAMPLES],
           english=_SR_HYBRID_ENGLISH)

add_sample('hr',
           'Franc Hlapić smješta ključ od gvožđa uz džbunje.',
           sources=[WP_PAN_HR], type=PARTIAL_PANGRAM, script='Latn',
           english='Franc Hlapic locates the iron key along the bushes')

add_sample('sl',
           'Šerif bo za domačo vajo spet kuhal žgance.',
           sources=[WP_PAN_SL, PANGO], type=PANGRAM, script='Latn',
           english='For an exercise, sheriff will again make home-made mush.')

add_sample('sl',
           'V kožuščku hudobnega fanta stopiclja mizar.',
           type=PANGRAM, script='Latn',
           sources=[WP_PAN_SL, WP_PANGRAMS_ARCHIVE_2014], flags=['redmond'],
           english='A cabinetmaker steps lightly through a malicious boy’s fur coat.')

add_sample('sl',
           'Pri Jakcu bom vzel šest čudežnih fig!',
           origin=PANGRAM_CONTEST_PZABAV,
           sources=[WP_PAN_SR], type=PANGRAM, script='Latn',
           english='At Jakac I took six magnificent figs!')


add_sample('sa', """
           कः खगौघाङचिच्छौजा झाञ्ज्ञोऽटौठीडडण्ढणः ।
           तथोदधीन्पफर्बाभीर्मयोऽरिल्वाशिषां सहः ॥ २६३ ॥
           """,
           origin='Sarasvatī-kaṇṭhābharaṇa by Bhoja',
           type=PARTIAL_PANGRAM, script='Deva',
           sources=['language games - Sanskrit pangram joke? - Linguistics Stack Exchange <https://linguistics.stackexchange.com/questions/20782/sanskrit-pangram-joke>'],
           english='Who is he, who assembles flocks of birds, has his mental energies intact, consumes the strength of others, is a scholar, is the lord of those who slay wanderers, is steadfast, and, without fear, filled the oceans? He is Maya, worthy of blessings that destroy enemies.')

add_sample('la',
           'Sic surgens, dux, zelotypos quam karus haberis',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn')

# TODO: Are pangrams without all accents pangrams, or partial pangrams?
#       Define better.
add_sample('fr',
           "Voix ambiguë d'un cœur qui au zéphyr préfère les jattes de kiwis.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, WP_PAN_FR, PANGO],
           type=PANGRAM_PARTIAL_ACCENTS, script='Latn',
           english='Ambiguous voice of a heart that, in the wind, prefers bowls of kiwis.',
           flags=['redmond'])

add_sample('fr',
           "Le vif zéphyr jubile sur les kumquats du clown gracieux.",
           sources=[WP_PAN_FR], type=PANGRAM_PARTIAL_ACCENTS, script='Latn',
           origin='Macintosh System 7',
           english='The lively zephyr exults over the kumquats of the graceful clown',
           flags=['old-mac'])

add_sample('fr',
           "Voyez le brick géant que j'examine près du wharf.",
           sources=[WP_PAN_FR], type=PANGRAM_PARTIAL_ACCENTS, script='Latn',
           english='See the giant brig that I examine near the wharf.',
           note="Used by International Telecommunication Union")

add_sample('ca',
           "Jove xef, porti whisky amb quinze glaçons d'hidrogen, coi!",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Latn',
           english='Young chef, bring whisky with fifteen hydrogen ice cubes, damn!')

add_sample('pt',
           "Luís argüia à Júlia que «brações, fé, chá, óxido, pôr, zângão» eram palavras do português.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english='Luís argued to Júlia that “big arms, faith, tea, oxide, to put, bee” were Portuguese words.')

add_sample('pt',
           "Vejam a bruxa da raposa Salta-Pocinhas e o cão feliz que dorme regalado.",
           sources=[PANGO, WP_SAMPLES], script='Latn',
           english='Watch the witch of the Jump-Puddles fox and the happy dog that sleeps delighted.')

add_sample('pt-br',
           "Zebras caolhas de Java querem passar fax para moças gigantes de New York",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="Strabic zebras from Java want to pass a fax to giant girls from New York.")

add_sample('pt-br',
           "À noite, vovô Kowalsky vê o ímã cair no pé do pingüim queixoso e vovó põe açúcar no chá de tâmaras do jabuti feliz",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Latn',
           english="At night, grandpa Kowalsky sees the magnet falling on the complaining penguin’s foot and grandma puts sugar in the happy tortoise’s date tea.")

add_sample('it',
           "Ma la volpe, col suo balzo, ha raggiunto il quieto Fido.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Latn',
           # Fido is a popular name for dogs in Italy
           english='But the fox, with its jump, reached the calm Benji.')

add_sample('it',
           "Pranzo d'acqua fa volti sghembi.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english='Water lunch makes twisted faces.')

add_sample('it',
           "Quel fez sghembo copre davanti.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english='That slanted fez covers the front.')

add_sample('ro',
           "Fumegând hipnotic sașiul azvârle mreje în bălți.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Latn',
           english="Hypnotically smoking, the cross-eyed man throws fishing nets into ponds.")

add_sample('ro',
           "Muzicologă în bej vând whisky și tequila, preț fix.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="Musicologist in beige, sells whisky and tequila, fixed price.")

add_sample('ro',
           "Înjurând pițigăiat, zoofobul comandă vexat whisky și tequila.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="Swearing in high pitch, the zoophobic man vexedly ordered whisky and tequila.")

add_sample('eo',
           "Eĥoŝanĝo ĉiuĵaŭde.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], script='Latn',
           english="Change of echo every Thursday")

add_sample('no',
           'Høvdingens kjære squaw får litt pizza i Mexico by.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="The chief's dear squaw gets a little pizza in Mexico City")

add_sample('no',
           'Vår sære Zulu fra badeøya spilte jo whist og quickstep i min taxi.',
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Latn',
           english="Our strange Zulu from the bathing Island did actually play whist and quickstep in my cab.")

add_sample('no',
           'En god stil må først og fremst være klar. Den må være passende. Aristoteles.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], script='Latn',
           english="A good essay must first and foremost be clear. It must be appropriate. Aristotle.")


add_sample('is',
           "Kæmi ný öxi hér ykist þjófum nú bæði víl og ádrepa.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Latn',
           english="If a new axe were here, thieves would feel increasing deterrence and punishment.")

add_sample('is',
           "Svo hölt, yxna kýr þegði jú um dóp í fé á bæ.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="A cow in heat with such a limp would admittedly keep silent about drugs in sheep on a farm.")

add_sample('is',
           "Þú dazt á hnéð í vök og yfir blóm sexý pæju.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="You fell on the knee in a hole in the ice and over a sexy girl’s flower.")


add_sample('sv',
           "Flygande bäckasiner söka strax hwila på mjuka tuvor.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Latn',
           english="Flying snipes soon look to rest on soft grass beds.",
           note="lacks q, x and z")

add_sample('sv',
           "Byxfjärmat föl gick på duvshowen.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="Trouser-estranged foal went to the pigeon show.",
           note="lacks q and z, extra f to include common ligatures fö and fj")

add_sample('sv',
           "Gud hjälpe Zorns mö qvickt få byxa.",
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="God must help Zorn's maiden get trousers quickly.",
           note="each letter once, old spelling 'qv', lacks foreign letter 'w'")

add_sample('da',
           "Quizdeltagerne spiste jordbær med fløde, mens cirkusklovnen Walther spillede på xylofon.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO], type=PANGRAM, script='Latn',
           english="The quiz contestants ate strawberries with cream while Walther the clown was playing the xylophone.")


add_sample('fy',
           'Alve bazige froulju wachtsje op dyn komst.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], type=PANGRAM, script='Latn',
           english="Eleven bossy women await your arrival.")


add_sample('nl',
           "Pa's wijze lynx bezag vroom het fikse aquaduct.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO],
           type=PANGRAM_PARTIAL_ACCENTS, script='Latn',
           english="Dad's wise lynx piously regarded the substantial aqueduct.")


add_sample('hu',
           "Egy hűtlen vejét fülöncsípő, dühös mexikói úr Wesselényinél mázol Quitóban.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO, WP_PAN_HU],
           type=PANGRAM, script='Latn',
           english="An angry Mexican man, who caught his faithless son-in-law, is painting Wesselényi's house in Quito.")

add_sample('hu',
           "Jámbor célú, öv ügyű ex-qwan ki dó-s főz, puhít.",
           sources=[WP_PAN_HU],
           type=PANGRAM, script='Latn',
           english="He is a ex-qwan-ki-do player with a belt who cooks and softens.")

add_sample('hu',
           "Pál fogyó IQ-jú kun exvő, ím dühös a WC bűzért.",
           sources=[WP_PAN_HU],
           type=PANGRAM, script='Latn',
           english="Paul is spending IQ when I'm leaving angry at the toilet smell.")

add_sample('fi',
           "Albert osti fagotin ja töräytti puhkuvan melodian.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="Albert bought a bassoon and blasted a puffing melody.",
           flags=['old-wordperfect'])

add_sample('fi',
           "On sangen hauskaa, että polkupyörä on maanteiden jokapäiväinen ilmiö.",
           sources=[WP_PAN_FI],
           type=PANGRAM, script='Latn',
           english="It's very funny that a bicycle is a daily road phenomenon")

add_sample('fi',
           "Eräänä jäätävänä ja pimeänä yönä gorilla ratkaisi sudokun kahdessa minuutissa.",
           sources=[WP_PAN_FI],
           type=PANGRAM, script='Latn',
           english="In one of the dark freezing nights, the gorilla solved the sudoku in under two minutes.")

add_sample('fi',
           "Viekas kettu punaturkki laiskan koiran takaa kurkki.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO],
           type=PHRASE, script='Latn',
           english="The cunning red-coated fox peeped from behind the lazy dog.")

add_sample('fi',
           "Törkylempijävongahdus.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, WP_PAN_FI],
           type=PERFECT_PANGRAM, script='Latn',
           english="Muckysnogger booty-call.")

add_sample('et',
           "See väike mölder jõuab rongile hüpata.",
           sources=[WP_PANGRAMS_ARCHIVE_2014, PANGO],
           type=PANGRAM, script='Latn',
           english="This small miller is able to jump to train.",
           flags=['redmond'])

add_sample('et',
           "Jubedalt möirgav lõukoer hüppas tänaval.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="Terribly roaring lion jumped on street.")

add_sample('et',
           "Põdur Zagrebi tšellomängija-följetonist Ciqo külmetas kehvas garaažis.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english='Ill-healthy cellist-feuilletonist Ciqo from Zagreb was being cold in a poor garage.',
           flags=['kde'])

add_sample('lv',
           "Glāžšķūņa rūķīši dzērumā čiepj Baha koncertflīģeļu vākus.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="Glass shack gnomes steal Bach piano covers while inebriated.")

add_sample('lv',
           "Četri psihi faķīri vēlu vakarā zāģēja guļbūvei durvis, fonā šņācot mežam.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="Late at night, four psycho conjurors were sawing the doors of a log cabin as the wind hummed in the background.")

add_sample('lv',
           "Muļķa hipiji mēģina brīvi nogaršot celofāna žņaudzējčūsku.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="Silly hippies try to freely taste the cellophane python.")

add_sample('lv',
           "Sarkanās jūrascūciņas peld pa jūru.",
           sources=[PANGO, WP_SAMPLES], type=PHRASE, script='Latn',
           english='Red seapigs swim in the sea.')

add_sample('lt',
           "Įlinkdama fechtuotojo špaga sublykčiojusi pragręžė apvalų arbūzą ",
           sources=[PANGO, WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="Incurving fencer sword sparkled and perforated a round watermelon")

add_sample('cs',
           "Příliš žluťoučký kůň úpěl ďábelské ódy.",
           sources=[PANGO, WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="A horse which was too yellow moaned devilish odes.")

add_sample('cs',
           "Červený střízlíček a špinavá žlůva ďobali šťavnaté ocúny.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="Small red wren and a dirty oriole picked juicy autumn crocus.")

add_sample('cs',
           "Zvlášť zákeřný učeň s ďolíčky běží podél zóny úlů ",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="An exceptionally insidious pupil with dimples runs along the beehive zone")

add_sample('sk',
           "Kŕdeľ šťastných ďatľov učí pri ústí Váhu mĺkveho koňa obhrýzať kôru a žrať čerstvé mäso.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Latn',
           english="A flock of happy woodpeckers by the mouth of the river Vah is teaching a silent horse to nibble on bark and feed on fresh meat.")

add_sample('pl',
           "Pchnąć w tę łódź jeża lub ośm skrzyń fig.",
           sources=[PANGO, WP_PANGRAMS_ARCHIVE_2014],
           type=PERFECT_PANGRAM, script='Latn',
           english="To push a hedgehog or eight crates of figs into this boat.")

add_sample('pl',
           "Mężny bądź, chroń pułk twój i sześć flag.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PERFECT_PANGRAM, script='Latn',
           english="Be brave, protect your regiment and six flags.")

add_sample('pl',
           "Pójdź w loch zbić małżeńską gęś futryn!",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PERFECT_PANGRAM, script='Latn',
           english="Go to the dungeon to batter the marital goose of doorframes!")

add_sample('mk',
           "Бучниов жолт џин ѕида куќа со фурна меѓу полиња за цреши, хмељ и грозје.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Cyrl',
           english="The noisy yellow genie is building a house with an oven in the midst of fields of cherries, hops and grapes.",
           translit="Buchniov zholt dzhin dzida kukja so furna megju polinja za creshi, hmelj i grozje.")

add_sample('mk',
           "Мојот дружељубив коњ со тих галоп фаќа брз џиновски глушец по туѓо ѕидче.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Cyrl',
           english="My friendly horse with a quiet gallop catches a quick giant mouse over someone else's little wall.",
           translit="Mojot druzheljubiv konj so tih galop fakja brz dzhinovski glushec po tugjo dzidche.")

add_sample('mk',
           "Долг Џош, сторив женење, црн ѕид! Фрчат хмељ, ќумбе, ѓупки, зајак.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Cyrl',
           english="Long Josh, I've done marriage, a black wall! Fly hops, stove, sponges, rabbit.",
           translit="Dolg Dzhosh, storiv zhenenje, crn dzid! Frchat hmelj, kjumbe, gjupki, zajak.")

add_sample('be',
           "У Іўі худы жвавы чорт у зялёнай камізэльцы пабег пад'есці фаршу з юшкай.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Cyrl',
           english="In Iwye a thin lively imp in a green vest ran eating soup with minced meat.",
           translit="U Iŭi chudy žvavy čort u zialionaj kamizeĺcy pabieh padjesci faršu z juškaj.")

add_sample('be',
           "У рудога вераб'я ў сховішчы пад фатэлем ляжаць нейкія гаючыя зёлкі.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Cyrl',
           english="In the red headed sparrow stored under the armchair lie some medicinal drugs.",
           translit="U rudoha vierabja ŭ schoviščy pad fateliem liažać niejkija hajučyja ziolki.")

add_sample('be',
           "Я жорстка заб'ю проста ў сэрца гэты расквечаны профіль, што ходзіць ля маёй хаты.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           type=PANGRAM, script='Cyrl',
           english="I strongly strike right in the heart this colorful outline that walks through my house.",
           translit="Ja žorstka zabju prosta ŭ serca hety raskviečany profiĺ, što chodzić lia majoj chaty.")

add_sample('hy',
           'Բել դղյակի ձախ ժամն օֆ ազգությանը ցպահանջ չճշտած վնաս էր և փառք։',
           english="During our time at the Bel's Castle there was an unspecified loss of honor and glory.",
           translit="Bel dghyaki dzakh zhamn of azgut’yany ts’pahanj ch’chshtats vnas er yev p’arrk’.",
           script='Armn', type=PANGRAM,
           sources=[FONTEST_IMPALLARI],
           origin='Hrant Papazian <https://twitter.com/hhpapazian>')


add_sample('ug', "زۆھرەگۈل ئابدۇۋاجىت فرانسىيەنىڭ پارىژدىكى خېلى بىشەم ئوقۇغۇچى.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           script='Arab',
           english="Those two roosters were not able to move to the mountain near Paris in France.")


add_sample('ug', "ئاۋۇ بىر جۈپ خوراز فرانسىيەنىڭ پارىژ شەھرىگە يېقىن تاغقا كۆچەلمىدى.",
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           script='Arab',
           english="Zöhregül Abduwajit is a quite unpleasant student in Paris, France.")


add_sample('ur', 'ٹھنڈ میں، ایک قحط زدہ گاؤں سے گذرتے وقت ایک چڑچڑے، باأثر و فارغ شخص کو بعض جل پری نما اژدہے نظر آئے۔',
           script='Arab', type=PANGRAM,
           sources=[WP_PANGRAMS_ARCHIVE_2014],
           english="In the cold, passing through an arid village, an irritable, influential and leisurely person saw some mermaid-like pythons.",
           translit="Ṭhanḍ meṉ, ek qaḥat̤-zadah gāʾoṉ se guẕarte waqt ek ciṛciṛe, bā-ʾas̱ar o-fārig̱ẖ s̱ẖaḵẖṣ ko baʿẓ jal-parī numā aẕẖdahe naz̤ar āʾe.")


# Don't have a translation for this one.
add_sample('yo', 'Ìwò̩fà ń yò̩ séji tó gbojúmó̩, ó hàn pákànpò̩ gan-an nis̩é̩ rè̩ bó dò̩la.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], script='Latn', type=PANGRAM)


add_sample('tl', 'Ang bawat rehistradong kalahok sa patimpalak ay umaasang magantimpalaan ng ñino.',
           english='Each participant who registered in the competition is hoping to be rewarded.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], script='Latn', type=PANGRAM,
           flags=['translation-wrong'])

JV_POEM_ENGLISH = 'There (were) two messengers; (they) had animosity (among each other); (they were) equally powerful (in fight); here are the corpses.'

add_sample('jv', 'Hanacaraka, datasawala, padhajayanya, magabathanga.',
           english=JV_POEM_ENGLISH,
           sources=[WP_PANGRAMS_ARCHIVE_2014], script='Latn')


# According to fontconfig/fc-lang/jv.orth and Wikipedia,
# the Javanese script is studied in school, but in very limited use.
# FIXME: Should still display it if we have the font...
#use_display_scripts('jv', ['Latn', 'Java'])
add_sample('jv', '꧋ ꦲꦤꦕꦫꦏ꧈ ꦢꦠꦱꦮꦭ꧈ ꦥꦝꦗꦪꦚ꧈ ꦩꦒꦧꦛꦔ꧉',
           english=JV_POEM_ENGLISH,
           sources=[WP_PANGRAMS_ARCHIVE_2014], script='Java', type=PANGRAM,
           prio=PRIO_WITHHOLD)


add_sample('my', 'သီဟိုဠ်မှ ဉာဏ်ကြီးရှင်သည် အာယုဝဍ္ဎနဆေးညွှန်းစာကို ဇလွန်ဈေးဘေးဗာဒံပင်ထက် အဓိဋ္ဌာန်လျက် ဂဃနဏဖတ်ခဲ့သည်။',
           english='The genius from Sri Lanka read the formula of elixir of life thoroughly in the almond tree next to Zalun market.',
           translit='seholmha nyarn kyee shinsai aaryu wad dh n sayy nywhaann hcarko jalwan jhayy bhayy bar dan painhtaat aadhithtaranlyet gaghanan hpaat hkaesai.',
           sources=[WP_PANGRAMS_ARCHIVE_2014], script='Mymr', type=PANGRAM)



# FIXME: Way too long.
# Translation unknown, something about elderly person, elephant, iris, gravitation, hare and turquoise, foot, oil and a turmeric plant.
add_sample('ml', 'അജവും ആനയും ഐരാവതവും ഗരുഡനും കഠോര സ്വരം പൊഴിക്കെ ഹാരവും ഒഢ്യാണവും ഫാലത്തില്‍ മഞ്ഞളും ഈറന്‍ കേശത്തില്‍ ഔഷധ എണ്ണയുമായി ഋതുമതിയും അനഘയും ഭൂനാഥയുമായ ഉമ ദുഃഖഛവിയോടെ ഇടതു പാദം ഏന്തി ങ്യേയാദൃശം നിര്‍ഝരിയിലെ ചിറ്റലകളെ ഓമനിക്കുമ്പോള്‍ ബാ‍ലയുടെ കണ്‍കളില്‍ നീര്‍ ഊര്‍ന്നു വിങ്ങി.',
           translit='ajavuṁ ānayuṁ airāvatavuṁ garuḍanuṁ kaṭhēāra svaraṁ peāḻikke hāravuṁ oḍhyāṇavuṁ phālattil maññaḷuṁ īṟan kēśattil auṣadha eṇṇayumāyi r̥tumatiyuṁ anaghayuṁ bhūnāthayumāya uma duḥkhachaviyēāṭe iṭatu pādaṁ ēnti ṅyēyādr̥śaṁ nirjhariyile ciṟṟalakaḷe ōmanikkumpēāḷ bā‍layuṭe kaṇkaḷil nīr ūrnnu viṅṅi.',
           type=PANGRAM, sources=[WP_PANGRAMS_ARCHIVE_2014],
           #prio=PRIO_WITHHOLD,
           script="Mlym")


# Translation unknown, too long, generally not good to display it. Though you
# can't do better to include all syllables...
add_sample('chr', 'ᎠᏍᎦᏯᎡᎦᎢᎾᎨᎢᎣᏍᏓᎤᎩᏍᏗᎥᎴᏓᎯᎲᎢᏔᎵᏕᎦᏟᏗᏖᎸᎳᏗᏗᎧᎵᎢᏘᎴᎩ ᏙᏱᏗᏜᏫᏗᏣᏚᎦᏫᏛᏄᏓᎦᏝᏃᎠᎾᏗᎭᏞᎦᎯᎦᏘᏓᏠᎨᏏᏕᏡᎬᏢᏓᏥᏩᏝᎡᎢᎪᎢ ᎠᎦᏂᏗᎮᎢᎫᎩᎬᏩᎴᎢᎠᏆᏅᏛᎫᏊᎾᎥᎠᏁᏙᎲᏐᏈᎵᎤᎩᎸᏓᏭᎷᏤᎢᏏᏉᏯᏌᏊ ᎤᏂᏋᎢᏡᎬᎢᎰᏩᎬᏤᎵᏍᏗᏱᎩᎱᎱᎤᎩᎴᎢᏦᎢᎠᏂᏧᏣᏨᎦᏥᎪᎥᏌᏊᎤᎶᏒᎢᎢᏡᎬᎢ ᎹᎦᎺᎵᏥᎻᎼᏏᎽᏗᏩᏂᎦᏘᎾᎿᎠᏁᎬᎢᏅᎩᎾᏂᎡᎢᏌᎶᎵᏎᎷᎠᏑᏍᏗᏪᎩ ᎠᎴ ᏬᏗᏲᏭᎾᏓᏍᏓᏴᏁᎢᎤᎦᏅᏮᏰᎵᏳᏂᎨᎢ.',
           type=PANGRAM, sources=[WP_PANGRAMS_ARCHIVE_2014],
           script='Cher', prio=PRIO_WITHHOLD)


use_display_scripts('mn', ['Cyrl'])

add_sample('mn', 'Щётканы фермд пийшин цувъя. Бөгж зогсч хэльюү.',
           translit="Shyotkany fyermd piishin tsuwiya. Bogj zogsch kheliyuu.",
           english="Let's echelon fireplaces in brush farm. Ring says standing.",
           type=PANGRAM, sources=[WP_PANGRAMS_ARCHIVE_2014],
           script='Cyrl')


# Translation unknown, possibly too long.
add_sample('bo', '༈ དཀར་མཛེས་ཨ་ཡིག་ལས་འཁྲུངས་ཡེ་ཤེས་གཏེར། །ཕས་རྒོལ་ཝ་སྐྱེས་ཟིལ་གནོན་གདོང་ལྔ་བཞིན། །ཆགས་ཐོགས་ཀུན་བྲལ་མཚུངས་མེད་འཇམ་བྱངས་མཐུས། །མ་ཧཱ་མཁས་པའི་གཙོ་བོ་ཉིད་གྱུར་ཅིག།',
           script='Tibt', type=PANGRAM,
           sources=[WP_PANGRAMS_ARCHIVE_2014])


# Translation unknown, possibly too long.
add_sample('dz', 'ཨ་ཡིག་དཀར་མཛེས་ལས་འཁྲུངས་ཤེས་བློའི་གཏེར༎ ཕས་རྒོལ་ཝ་སྐྱེས་ཟིལ་གནོན་གདོང་ལྔ་བཞིན༎ ཆགས་ཐོགས་ཀུན་བྲལ་མཚུངས་མེད་འཇམ་དབྱངསམཐུས༎ མཧཱ་མཁས་པའི་གཙོ་བོ་ཉིད་འགྱུར་ཅིག།',
           script='Tibt', type=PANGRAM,
           sources=[WP_PANGRAMS_ARCHIVE_2014])


# TO CHECK
add_sample('arn', "Gvxam mincetu apocikvyeh: ñizol ce mamvj ka raq kuse bafkeh mew.",
           english="Tale under the full moon: the chief chemamull and the clay old woman at the lake/sea.",
           script='Latn', type=PANGRAM,
           sources=[PANGO, WP_PANGRAMS_ARCHIVE_2014])


add_sample('ga', 'Ċuaiġ bé ṁórṡáċ le dlúṫspád fíorḟinn trí hata mo ḋea-ṗorcáin ḃig.',
           english='A greatly satisfied woman went with a truly white dense spade through the hat of my good little well-fattened pig',
           script='Latn', type=PANGRAM,
           sources=[PANGO, WP_PANGRAMS_ARCHIVE_2014])

add_sample('gd', "Mus d'fhàg Cèit-Ùna ròp Ì le ob.",
           english="Before Kate-Una left the Iona cattle auction with hops.",
           script='Latn', type=PANGRAM,
           sources=[WP_PANGRAMS_ARCHIVE_2014])




IROHA_NOTE = 'Iroha poem. Covers all of Hiragana.'
IROHA_ENGLISH =  '''
           Even the blossoming flowers [Colors are fragrant, but they]
           Will eventually scatter
           Who in our world
           Is unchanging?
           The deep mountains of karma—
           We cross them today
           And we shall not have superficial dreams
           Nor be deluded.
           '''

use_display_scripts('ja', ['Jpan', 'Hira'])

add_sample('ja', '''
           いろはにほへと　ちりぬるを
           わかよたれそ　　つねならむ
           うゐのおくやま　けふこえて
           あさきゆめみし　ゑひもせす
           ''',
           script='Hira', sources=[WP_IROHA], type=SYLLABLE_PANGRAM,
           english=IROHA_ENGLISH,
           note=IROHA_NOTE,
           flags=['long-only', 'can-squeeze'])



add_sample('ja', '''
           色はにほへど　散りぬるを
           我が世たれぞ　常ならむ
           有為の奥山　　今日越えて
           浅き夢見じ　　酔ひもせず
           ''',
           script='Jpan', sources=[WP_IROHA], type=PHRASE,
           english=IROHA_ENGLISH,
           note=IROHA_NOTE,
           flags=['long-only', 'can-squeeze', 'no-display'])


add_sample('zh', '''
           1
           天地玄黃，宇宙洪荒。
           日月盈昃，辰宿列張。
           寒來暑往，秋收冬藏。
           閏餘成歲，律呂調陽。
           雲騰致雨，露結為霜。
           金生麗水，玉出崑岡。
           劍號巨闕，珠稱夜光。
           果珍李柰，菜重芥姜。
           海咸河淡，鱗潛羽翔。

           2
           龍師火帝，鳥官人皇。
           始制文字，乃服衣裳。
           推位讓國，有虞陶唐。
           弔民伐罪，周發殷湯。
           坐朝問道，垂拱平章。
           愛育黎首，臣伏戎羌。
           遐邇一體，率賓歸王。
           鳴鳳在竹，白駒食場。
           化被草木，賴及萬方。

           3
           蓋此身髮，四大五常。
           恭惟鞠養，豈敢毀傷。
           女慕貞絜，男效才良。
           知過必改，得能莫忘。
           罔談彼短，靡恃己長。
           信使可覆，器欲難量。
           墨悲絲染，詩讚羔羊。
           景行維賢，克念作聖。
           德建名立，形端表正。
           空谷傳聲，虛堂習聽。
           禍因惡積，福緣善慶。
           尺璧非寶，寸陰是競。
           資父事君，曰嚴與敬。
           孝當竭力，忠則盡命。
           臨深履薄，夙興溫凊。
           似蘭斯馨，如松之盛。
           川流不息，淵澄取映。
           容止若思，言辭安定。
           篤初誠美，慎終宜令。
           榮業所基，藉甚無竟。
           學優登仕，攝職從政。
           存以甘棠，去而益詠。
           樂殊貴賤，禮別尊卑。
           上和下睦，夫唱婦隨。
           外受傅訓，入奉母儀。
           諸姑伯叔，猶子比兒。
           孔懷兄弟，同氣連根。
           交友投分，切磨箴規。
           仁慈隱惻，造次弗離。
           節義廉退，顛沛匪虧。
           性靜情逸，心動神疲。
           守真志滿，逐物意移。
           堅持雅操，好爵自縻。

           4
           都邑華夏，東西二京。
           背邙面洛，浮渭據涇。
           宮殿盤郁，樓觀飛驚。
           圖寫禽獸，畫彩仙靈。
           丙舍傍啟，甲帳對楹。
           肆筵設席，鼓瑟吹笙。
           升階納陛，弁轉疑星。
           右通廣內，左達承明。
           既集墳典，亦聚群英。
           杜稿鍾隸，漆書壁經。
           府羅將相，路俠槐卿。
           戶封八縣，家給千兵。
           高冠陪輦，驅轂振纓。
           世祿侈富，車駕肥輕。
           策功茂實，勒碑刻銘。
           磻溪伊尹，佐時阿衡。
           奄宅曲阜，微旦孰營。
           桓公匡合，濟弱扶傾。
           綺回漢惠，說感武丁。
           俊乂密勿，多士寔寧。
           晉楚更霸，趙魏困橫。
           假途滅虢，踐土會盟。
           何遵約法，韓弊煩刑。
           起翦頗牧，用軍最精。
           宣威沙漠，馳譽丹青。
           九州禹跡，百郡秦并。
           岳宗泰岱，禪主云亭。
           雁門紫塞，雞田赤城。
           昆池碣石，鉅野洞庭。
           曠遠綿邈，岩岫杳冥。

           5
           治本於農，務茲稼穡。
           俶載南畝，我藝黍稷。
           稅熟貢新，勸賞黜陟。
           孟軻敦素，史魚秉直。
           庶幾中庸，勞謙謹敕。
           聆音察理，鑒貌辨色。
           貽厥嘉猷，勉其祗植。
           省躬譏誡，寵增抗極。
           殆辱近恥，林皋幸即。
           兩疏見機，解組誰逼。
           索居閒處，沉默寂寥。
           求古尋論，散慮逍遙。
           欣奏累遣，慼謝歡招。
           渠荷的歷，園莽抽條。
           枇杷晚翠，梧桐蚤凋。
           陳根委翳，落葉飄搖。
           游鵾獨運，凌摩絳霄。

           6
           耽讀玩市，寓目囊箱。
           易輶攸畏，屬耳垣牆。
           具膳餐飯，適口充腸。
           飽飫烹宰，飢厭糟糠。
           親戚故舊，老少異糧。
           妾御績紡，待巾帷房。
           紈扇圓潔，銀燭煒煌。
           晝眠夕寐，藍筍象床。
           弦歌酒宴，接杯舉觴。
           矯手頓足，悅豫且康。
           嫡後嗣續，祭祀烝嘗。
           稽顙再拜，悚懼恐惶。
           箋牒簡要，顧答審詳。
           骸垢想浴，執熱願涼。
           驢騾犢特，駭躍超驤。
           誅斬賊盜，捕獲叛亡。

           7
           布射僚丸，嵇琴阮嘯。
           恬筆倫紙，鈞巧任釣。
           釋紛利俗，竝皆佳妙。
           毛施淑姿，工顰妍笑。
           年矢每催，曦暉朗曜。
           璿璣懸斡，晦魄環照。
           指薪修祜，永綏吉劭。
           矩步引領，俯仰廊廟。
           束帶矜庄，徘徊瞻眺。
           孤陋寡聞，愚蒙等誚。
           謂語助者，焉哉乎也。''',
           sources=[WP_THOUSAND_CHARACTER], type=PHRASE, script='Hant',
           note='Thousand Character Poem (千字文)',
           flags=['long-only'])

add_sample('zh',
           '視野無限廣，窗外有藍天', type=PHRASE, script='Hant',
           english='The view is infinitely wide. '
                   'There is blue sky outside the window.',
           sources=[WP_PANGRAMS_ARCHIVE_2014])

add_sample('zh',
           '微風迎客，軟語伴茶', type=PHRASE, script='Hant',
           english='The breeze sees the guest in. '
                   'Soft voice accompanies the tea.',
           sources=[WP_PANGRAMS_ARCHIVE_2014])

YONG = add_sample('zh', '永', type=YONG_CHARACTER, script='Han',
           english='Permanence', translit='Yǒng',
           sources=['Eight Principles of Yong - Wikipedia, 07:09, 23 March 2018 <https://en.wikipedia.org/w/index.php?title=Eight_Principles_of_Yong&oldid=832003321>'],
           flags=['non-default'])

use_display_scripts('zh-cn', ['Hans'])
use_display_scripts('zh-mo', ['Hant'])
use_display_scripts('zh-sg', ['Hans'])
use_display_scripts('zh-tw', ['Hant'])

# Various.

add_sample('ja', '市内には世界的に知られた地区やランドマークが数多くある。',
           script='Jpan',
           sources=['ニューヨーク - Wikipedia、2018年4月5日 (木) 07:04 <https://ja.wikipedia.org/w/index.php?title=%E3%83%8B%E3%83%A5%E3%83%BC%E3%83%A8%E3%83%BC%E3%82%AF&oldid=68001656>'],
           english='There are many areas and landmarks known worldwide in the city.',
           translit='Shinai ni wa sekai-teki ni shira reta chiku ya randomāku ga kazuōku aru.')

add_sample('ja', '毎年ゴールデンウイークの序盤と終盤において、主要ターミナル駅・空港などでは多くの乗客が見られる。',
           script='Jpan',
           sources=['ゴールデンウィーク - Wikipedia、2018年5月14日 (月) 15:30 <https://ja.wikipedia.org/w/index.php?title=%E3%82%B4%E3%83%BC%E3%83%AB%E3%83%87%E3%83%B3%E3%82%A6%E3%82%A3%E3%83%BC%E3%82%AF&oldid=68563177>'],
           english='Anually, at the beginning and the end of the Golden Week, many passengers can be seen at the major terminal stations and airports.',
           translit="Maitoshi gōruden'uīku no joban to shūban ni oite, shuyō tāminaru-eki kūkō nadode wa ōku no jōkyaku ga mi rareru.")

add_sample('ja', 'キノコを食べる動物はヒト以外にも多い。',
           script='Jpan',
           sources=['キノコ - Wikipedia, 2018年5月27日 (日) 21:14 <https://ja.wikipedia.org/w/index.php?title=%E3%82%AD%E3%83%8E%E3%82%B3&oldid=68705858>'],
           english='There are many animals other than humans to eat mushrooms.',
           translit='Kinoko o taberu dōbutsu wa hito igai ni mo ōi.')

add_sample('oc',
           "Lo fruch se pòt manjar crus o torrat.",
           script='Latn',
           english='The fruit can be eaten raw or cooked.',
           sources=['Agland - Wikipèdia, 1 julhet de 2015 a 16.40 <https://oc.wikipedia.org/w/index.php?title=Agland&oldid=1967879>'])


add_sample('wa',
           "Ene operete, c' est ene pitite operå, mins todi djoyeuse.",
           script='Latn',
           english="An operetta, that's a shorter opera, but one that is always happy.",
           sources=['Operete — Wikipedia, 21 setimbe 2014 à 13:59 <https://wa.wikipedia.org/w/index.php?title=Operete&oldid=309729>'])

WP_ELECTRIC_ENERGY_EU = 'Energia elektrikoa garraiatzeko aireko linea - Wikipedia, entziklopedia askea. 22:09, 17 maiatza 2018 <https://eu.wikipedia.org/w/index.php?title=Energia_elektrikoa_garraiatzeko_aireko_linea&oldid=6229189>'

add_sample('eu',
           "Egiturak diseinatzerakoan eroaleek sortutako indar guztiak kontuan izan behar dira.",
           script='Latn',
           english="When designing the structures, all the forces generated by conductors must be taken into account.",
           sources=[WP_ELECTRIC_ENERGY_EU])
add_sample('eu',
           "Aireko linea elektrikoen egiturak mota askotakoak izan daitezke, linea motaren arabera.",
           script='Latn',
           english="Electric air line structures can be varied depending on the type of line.",
           sources=[WP_ELECTRIC_ENERGY_EU])

add_sample('an',
           "Un eclix ye un fenomen astronomico que se produce quan un obchecto celestial se mueve a traviés d'a uembra d'un atro.",
           script='Latn',
           english="An eclipse is an astronomical phenomenon that occurs when one a celestial body appears in front of another.",
           sources=['Eclix - Biquipedia, a enciclopedia libre, 17:54 3 avi 2013 <https://an.wikipedia.org/w/index.php?title=Eclix&oldid=1532842>'])


add_sample('gl',
           "Os elefantes son animais herbívoros que se alimentan de herba e follas de árbores.",
           script='Latn',
           english="Elephants are herbivorous animals that feed on grasses and leaves of trees.",
           sources=['Elefante - Wikipedia, a enciclopedia libre, 2017 ás 23:38 <https://gl.wikipedia.org/w/index.php?title=Elefante&oldid=4549969>'])

add_sample('kw',
           "War oll an norvys 'th on ni skollys a-les.",
           script='Latn',
           english='Over all the world, we are spread far and wide.',
           sources=['Cornish language - Wikipedia, 17:08, 27 May 2018 <https://en.wikipedia.org/w/index.php?title=Cornish_language&oldid=843210556>'])


WP_ROMANSH = 'Energia geotermica - Wikipedia, 23:42, 12 december 2017 <https://en.wikipedia.org/w/index.php?title=Romansh_language&oldid=842512172>'

add_sample('rm',
           'Sche tes chant è uschè bel sco tia parita, lur es ti il pli bel utschè da tuts.',
           script='Latn',
           english='If your singing is as beautiful as your looks, then you are the most beautiful of all birds.',
           sources=[WP_ROMANSH])

add_sample('rm',
           "Qua ha ella vis sin in pign in corv che tegneva in toc chaschiel en ses pichel.",
           script='Latn',
           english='There, he saw a raven upon a fir holding a piece of cheese in its beak.',
           sources=[WP_ROMANSH])

add_sample('rm',
           "En territoris betg vulcanics pon las temperaturas en il sutterran variar fermamain.",
           script='Latn',
           english='In territories with volcanoes the subterranean temperatures vary a lot', # ???
           sources=['Energia geotermica - Wikipedia, 23:42, 12 december 2017 <https://rm.wikipedia.org/w/index.php?title=Energia_geotermica&oldid=153827>'])



WP_WELSH = 'Welsh language - Wikipedia, 10:40, 3 June 2018 <https://en.wikipedia.org/w/index.php?title=Welsh_language&oldid=844206066>'

add_sample('cy',
           "Fyddan nhw'n cysgu ddim ond pan fydd angen.",
           script='Latn',
           english="They'll sleep only when there's a need.",
           sources=[WP_WELSH])

add_sample('cy',
           "Doedd o ddim wedi sefyll yno'n hir.",
           script='Latn',
           english="He had not stood there long.",
           sources=[WP_WELSH])

add_sample('cy',
           "Rwy'n codi'n gynnar bob dydd.",
           script='Latn',
           english="I get up early every day.",
           sources=[WP_WELSH])

add_sample('gv',
           "Dooyrt ee dy row ee gra eh tra v'ee inneen veg, agh t'eh ooilley jarroodit eck.",
           script='Latn',
           english="She said that she used to say it when she was a little girl.",
           sources=['Manx language - Wikipedia, 20:09, 14 May 2018 <https://en.wikipedia.org/w/index.php?title=Manx_language&oldid=841257755>'])


WP_ESTONIA_FO = 'Estland - Wikipedia, 20. des 2017 kl. 23:07 <https://fo.wikipedia.org/w/index.php?title=Estland&oldid=346633>'

add_sample('fo',
           "Í støðum eru stórar mýrar, sum teir skera torv í.",
           english="The wharfes are large marshland which cuts the turf in.",
           sources=[WP_ESTONIA_FO], script='Latn',
           flags=['translation-wrong'])


add_sample('fo',
           "Hetta kemur av tí, at jørðin nógvastaðni er so botnvát, at hon ber einki uttan gras.",
           english="The cap is there because the country has no grassland from the outside.",
           sources=[WP_ESTONIA_FO], script='Latn',
           flags=['translation-wrong'])


WP_LITTLE_SWITZERLAND_LB = 'Kleng Lëtzebuerger Schwäiz - Wikipedia, 10:27, 28. Jan. 2018 <https://lb.wikipedia.org/w/index.php?title=Kleng_L%C3%ABtzebuerger_Schw%C3%A4iz&oldid=2095319>'

add_sample('lb', 
           "Den Äisbier, och Polarbier genannt, ass e Fleeschfrësser aus der Famill vun de Bieren.",
           english="The äisbier, or the polar bear, is a carnivourous from the bears family.",
           script='Latn',
           sources=['Äisbier - Wikipedia, 22:51, 18. Jan. 2018 <https://lb.wikipedia.org/w/index.php?title=%C3%84isbier&oldid=2092887>'])

add_sample('lb', 
           "D'Hielen a Fielsvirspréng an der Géigend hu schonn an der Alsteenzäit de Mënsche Schutz gebueden.",
           script='Latn',
           english="The hills and rock formations in the area have sheltered humans in the early days.",
           sources=[WP_LITTLE_SWITZERLAND_LB])

add_sample('lb', 
           "D'Réimer hunn d'Fielsen als Steebroch benotzt.",
           script='Latn',
           english="The Romans used the rock formations as a quarry.",
           sources=[WP_LITTLE_SWITZERLAND_LB])

WP_AFRICA_KA = 'აფრიკა - ვიკიპედია, 15:37, 18 იანვარი 2018 <https://ka.wikipedia.org/w/index.php?title=%E1%83%90%E1%83%A4%E1%83%A0%E1%83%98%E1%83%99%E1%83%90&oldid=3432979>'


add_sample('ka', 'ზამბეზი ინდოეთის ოკეანის ყველაზე დიდი მდინარეა.',
           sources=[WP_AFRICA_KA], script='Geor',
           translit='zambezi indoetis okeanis yvelaze didi mdinarea.',
           english='Zambezi is the largest river flowing into the Indian ocean')

add_sample('ka', 'ვიქტორიის ტბა ფართობით ყველაზე დიდია აფრიკაში.',
           sources=[WP_AFRICA_KA], script='Geor',
           translit='viqtoriis tba fartobit yvelaze didia afrikashi.',
           english="Lake Victoria is the largest in Africa.")

add_sample('ka', 'ტყეებში მწერების დიდი რაოდენობაა.',
           sources=[WP_AFRICA_KA], script='Geor',
           translit='tyeebshi mtserebis didi raodenobaa.',
           english='There are a lot of insects in the woods.')


WP_AZERBAIJAN_KA = 'აზერბაიჯანი - ვიკიპედია, 06:49, 24 მაისი 2018-ის <https://ka.wikipedia.org/w/index.php?title=%E1%83%90%E1%83%96%E1%83%94%E1%83%A0%E1%83%91%E1%83%90%E1%83%98%E1%83%AF%E1%83%90%E1%83%9C%E1%83%98&oldid=3498786>'

add_sample('ka',
           'ადრეული დასახლებები შეიცავს, ძვ. წ. IX საუკუნის სკვითებსაც.',
           sources=[WP_AZERBAIJAN_KA], script='Geor',
           translit="adreuli dasakhlebebi sheitsavs, dzv. ts. IX saukunis skvitebsats.",
           english='Early settlements included the Scythians in the 9th century BC.')


add_sample('ka',
           'მხოლოდ 24 მდინარეს აქვს 100 კილომეტრზე მეტი სიგრძე.',
           sources=[WP_AZERBAIJAN_KA], script='Geor',
           english='Only 24 of the rivers are longer than 100 km.',
           translit='mkholod 24 mdinares akvs 100 kilometrze meti sigrdze.')



WP_CRETE_HY = 'Կրետե - Վիքիպեդիա՝ ազատ հանրագիտարան, 14:47, 12 Դեկտեմբերի 2016 <https://hy.wikipedia.org/w/index.php?title=%D4%BF%D6%80%D5%A5%D5%BF%D5%A5&oldid=4737063>'


add_sample('hy',
           'Աթենաս աստվածուհին լողացել է Վուլիսմենի լճում։',
           script='Armn',
           translit='At’enas astvatsuhin loghats’el e Vulismeni lchum.',
           english='Goddess Athena swam in lake Voulismeni',
           sources=[WP_CRETE_HY])

add_sample('hy',
           'Զևս աստվածը Կրետեում շանթահարեց կղզին ահաբեկող հսկա մողեսին։',
           script='Armn',
           english='Zeus crushed the gigantic lizard that terrorized the island in Crete.',
           translit='Zevs astvatsy Kreteum shant’aharets’ kghzin ahabekogh hska moghesin.',
           sources=[WP_CRETE_HY])

add_sample('hy',
           'Մադագասկարը մայրցամաքից բաժանվում է Մոզամբիկի լայն նեղուցով։',
           script='Armn',
           english='Madagascar is separated from the continent by the wide strait of Mozambique.',
           translit='Madagaskary mayrts’amak’its’ bazhanvum e Mozambiki layn neghuts’ov.',
           sources=['Աֆրիկա - Վիքիպեդիա՝ ազատ հանրագիտարան, 21:53, 4 Մայիսի 2018  <https://hy.wikipedia.org/w/index.php?title=%D4%B1%D6%86%D6%80%D5%AB%D5%AF%D5%A1&oldid=5743237>'])

add_sample('hy',
           'Գործարկումից հետո այն կդառնա ամենամեծ նավն իր դասի մեջ։',
           script='Armn',
           english='After its launch, it will be the largest ship in its class.',
           translit='Gortsarkumits’ heto ayn kdarrna amenamets navn ir dasi mej.',
           sources=['Նյու Յորք - Վիքիպեդիա՝ ազատ հանրագիտարան, 18:25, 30 Մարտի 2018 <https://hy.wikipedia.org/w/index.php?title=%D5%86%D5%B5%D5%B8%D6%82_%D5%85%D5%B8%D6%80%D6%84&oldid=5707433>'])

WQ_PABLO_PICASSO_SQ = 'Pablo Picasso - WikiCitate, 5 janar 2016 23:46 <https://sq.wikiquote.org/w/index.php?title=Pablo_Picasso&oldid=8323>'

add_sample('sq',
           'Arti është gënjeshtra përmes së cilës kuptojmë të vërtetën.',
           script='Latn',
           english='Art is a lie that makes us understand the truth.',
           sources=['Portal:Arti - Wikipedia, 20 nëntor 2014 18:24 <https://sq.wikipedia.org/w/index.php?title=Portal:Arti&oldid=1472140>', WQ_PABLO_PICASSO_SQ],
           origin='Pablo Picasso')


add_sample('sq',
           'Artistët e mirë kopjojnë. Artistët e shkëlqyeshëm vjedhin.',
           script='Latn',
           english='Good artists copy. Great artists steal.',
           sources=[WQ_PABLO_PICASSO_SQ],
           origin='Pablo Picasso')

add_sample('sq',
           'Ka dallim mes të diturit e rrugës dhe të ecurit e rrugës.',
           script='Latn',
           english="There's a difference between knowing the path and walking the path.",
           sources=['The Matrix, WikiCitate, 9 gusht 2015 09:36 <https://sq.wikiquote.org/w/index.php?title=The_Matrix&oldid=8219>'],
           origin='Morpheus to Neo, “The Matrix”')


WQ_BEN_FRANKLIN_AF = 'Benjamin Franklin - Wikiquote, 17:37, 14 April 2014 <https://af.wikiquote.org/w/index.php?title=Benjamin_Franklin&oldid=7494>'
ORIGIN_NOT_FRANKLIN = "Unknown, probably not Benjamin Franklin"

add_sample('af',
           "As jy van 'n lastige besoeker ontslae wil raak, leen aan hom geld.",
           english="If you’d lose a troublesome visitor, lend him money",
           origin=ORIGIN_NOT_FRANKLIN, script='Latn',
           sources=[WQ_BEN_FRANKLIN_AF])

add_sample('af',
           'As jy wil vasstel wat die waarde van geld is, probeer dit leen.',
           english='If you would know the value of money, go and try to borrow some.',
           origin=ORIGIN_NOT_FRANKLIN, script='Latn',
           sources=[WQ_BEN_FRANKLIN_AF])

add_sample('af',
           'Wat jy ookal doen, trap op die beledigings en bemin dié wat vir jou lief is.',
           english='Whatever you do, crush the infamous thing, and love those who love you.',
           original="Quoi que vous fassiez, écrasez l'infâme, et aimez qui vous aime.",
           origin='Voltaire', script='Latn',
           sources=['Voltaire - Wikipedia, 21:17, 15 April 2014 <https://af.wikiquote.org/w/index.php?title=Voltaire&oldid=7547>',
                    'Voltaire - Wikipedia, 07:30, 2 May 2018 <https://en.wikiquote.org/w/index.php?title=Voltaire&oldid=2399679>'])

WP_CANOE_BN = 'নৌকা বাইচ - উইকিপিডিয়া <https://bn.wikipedia.org/w/index.php?title=%E0%A6%A8%E0%A7%8C%E0%A6%95%E0%A6%BE_%E0%A6%AC%E0%A6%BE%E0%A6%87%E0%A6%9A&oldid=2911169>'



add_sample('bn',
           'ভিন্ন কম্পাঙ্কের বেতার তরঙ্গের বৈশিষ্ট্য ভিন্ন রকম হয়।',
           script='Beng',
           english='The propagation charactertics of radio wave of different frequencies differ.',
           translit='Bhinna kampāṅkēra bētāra taraṅgēra baiśiṣṭya bhinna rakama haẏa.',
           sources=['বেতার তরঙ্গ - উইকিপিডিয়া, ০৭:৪৮, ২৬ মার্চ ২০১৮ <https://bn.wikipedia.org/wiki/%E0%A6%AC%E0%A7%87%E0%A6%A4%E0%A6%BE%E0%A6%B0_%E0%A6%A4%E0%A6%B0%E0%A6%99%E0%A7%8D%E0%A6%97>'])

add_sample('bn',
           'বাইচের নৌকাগুলোর বিভিন্ন নাম রয়েছে।',
           script='Beng',
           english='The boat for riding have different names.',
           translit="Bā'icēra naukāgulōra bibhinna nāma raẏēchē.")

add_sample('bn', 'তাতে কখনো করা হয় ময়ূরের মুখ, কখনো রাজহাঁস বা অন্য কোনো পাখীর মুখাবয়ব।',
           script='Beng',
           english="It is sometimes the beak of a peacock, swan or other bird.",
           translit="Tātē kakhanō karā haẏa maẏūrēra mukha, kakhanō rājahām̐sa bā an'ya kōnō pākhīra mukhābaẏaba.",
           sources=[WP_CANOE_BN])

WP_NANOTECH_MR = 'अतिसूक्ष्मतंत्रज्ञान - विकिपीडिया, ०८:४५, १३ ऑक्टोबर २०१४चे <https://mr.wikipedia.org/w/index.php?title=%E0%A4%85%E0%A4%A4%E0%A4%BF%E0%A4%B8%E0%A5%82%E0%A4%95%E0%A5%8D%E0%A4%B7%E0%A5%8D%E0%A4%AE%E0%A4%A4%E0%A4%82%E0%A4%A4%E0%A5%8D%E0%A4%B0%E0%A4%9C%E0%A5%8D%E0%A4%9E%E0%A4%BE%E0%A4%A8&oldid=1272535>'

add_sample('mr', 'इतक्या सूक्ष्म वस्तूंना नियंत्रित करणे ही महत्कठीण अशी एक बाब आहे.',
           script='Deva',
           english="That level of control on such small scale is of great significance.",
           translit='Itakyā sūkṣma vastūnnā niyantrita karaṇē hī mahatkaṭhīṇa aśī ēka bāba āhē.',
           sources=[WP_NANOTECH_MR])


add_sample('mr', 'त्यात केवळ चित्रे काळ्या रंगाने बाह्यरेषा चित्र काढले आहेत.',
           script='Deva',
           english='It features only pictures drawn using line art outlines.',
           translit='Tyāta kēvaḷa citrē kāḷyā raṅgānē bāhyarēṣā citra kāḍhalē āhēta.',
           sources=['अस्तेक प्राचीन ग्रंथ - विकिपीडिया, २१:१३, १६ ऑगस्ट २०१६चे <https://mr.wikipedia.org/w/index.php?title=%E0%A4%85%E0%A4%B8%E0%A5%8D%E0%A4%A4%E0%A5%87%E0%A4%95_%E0%A4%AA%E0%A5%8D%E0%A4%B0%E0%A4%BE%E0%A4%9A%E0%A5%80%E0%A4%A8_%E0%A4%97%E0%A5%8D%E0%A4%B0%E0%A4%82%E0%A4%A5&oldid=1408713>'])

add_sample('mr', 'असा संदेश मतदारांना आकर्षित करु शकेलच असे नाही.',
           script='Deva',
           english="Such message would not appeal to voters.",
           translit='Asā sandēśa matadārānnā ākarṣita karu śakēlaca asē nāhī.',
           sources=['राजकीय प्रचार - विकिपीडिया, १७:५०, २४ फेब्रुवारी २०१७चे <https://mr.wikipedia.org/w/index.php?title=%E0%A4%B0%E0%A4%BE%E0%A4%9C%E0%A4%95%E0%A5%80%E0%A4%AF_%E0%A4%AA%E0%A5%8D%E0%A4%B0%E0%A4%9A%E0%A4%BE%E0%A4%B0&oldid=1446275>'])

WQ_ARISTOTLE_KN = 'ಅರಿಸ್ಟಾಟಲ್ - ವಿಕಿಕೋಟ್, ೧೦:೨೪, ೧೪ ಏಪ್ರಿಲ್ ೨೦೧೮ <https://kn.wikiquote.org/w/index.php?title=%E0%B2%85%E0%B2%B0%E0%B2%BF%E0%B2%B8%E0%B3%8D%E0%B2%9F%E0%B2%BE%E0%B2%9F%E0%B2%B2%E0%B3%8D&oldid=8113>'
WQ_ARISTOTLE_EN = 'Aristotle - Wikiquote, 20:55, 26 May 2018 <https://en.wikiquote.org/w/index.php?title=Aristotle&oldid=2409555>'

add_sample('kn', 'ಒಳ್ಳೆಯ ಆರಂಭ ಎಂದರೆ ಕೆಲಸ ಅರ್ಧ ಮುಗಿಯಿತು ಎಂದೇ.',
           script='Knda',
           english='Well begun is half done.',
           translit='Oḷḷeya ārambha endare kelasa ardha mugiyitu endē.',
           origin='Politics by Aristotles, Book V, 1303b.19-30',
           sources=[WQ_ARISTOTLE_KN, WQ_ARISTOTLE_KN])

add_sample('kn', 'ಬೇರೆಯವರ ಆಲೋಚನೆಗಳನ್ನು ಒಪ್ಪಿಕೊಳ್ಳದಿದ್ದರೂ, ಅವರ ಮಾತನ್ನು ತಾಳ್ಮೆಯಿಂದ ಆಲಿಸುವುದು ಸುಶಿಕ್ಷಿತ ಮನಸ್ಸಿನ ಸಂಕೇತ.',
           script='Knda',
           english='It is the mark of an educated mind to be able to entertain a thought without accepting it.',
           translit="Bēreyavara ālōcanegaḷannu oppikoḷḷadiddarū, avara mātannu tāḷmeyinda ālisuvudu suśikṣita manas'sina saṅkēta.",
           sources=[WQ_ARISTOTLE_KN],
           origin='Misattributed to Aristotle in Lowell L. Bennion, Religion and the Pursuit of Truth')

add_sample('kn', 'ಗುಣದ ಬಗ್ಗೆ ತಿಳಿದುಕೊಂಡರೆ ಸಾಲದು, ಅದನ್ನು ಉಳ್ಳವನಾಗಲು ಯತ್ನಿಸಬೇಕು.',
           script='Knda',
           english='With regard to excellence, it is not enough to know, but we must try to have and use it.',
           translit='Guṇada bagge tiḷidukoṇḍare sāladu, adannu uḷḷavanāgalu yatnisabēku.',
           sources=[WQ_ARISTOTLE_KN],
           origin='Probably not Aristotle (similar to commonly misattributed quote)')

WQ_MANDELA_TA = 'நெல்சன் மண்டேலா - விக்கிமேற்கோள், 06:44, 8 பெப்ரவரி 2018 <https://ta.wikiquote.org/w/index.php?title=%E0%AE%A8%E0%AF%86%E0%AE%B2%E0%AF%8D%E0%AE%9A%E0%AE%A9%E0%AF%8D_%E0%AE%AE%E0%AE%A3%E0%AF%8D%E0%AE%9F%E0%AF%87%E0%AE%B2%E0%AE%BE&oldid=15046>'
WQ_MANDELA_EN = 'Nelson Mandela - Wikiquote, 06:45, 30 April 2018 <https://en.wikiquote.org/w/index.php?title=Nelson_Mandela&oldid=2398814>'

add_sample('ta', 'கல்வியே உலகை மாற்றக்கூடிய சக்தி மிக்க ஆயுதம்.',
           script='Taml',
           english='Education is the most powerful weapon we can use to change the world.',
           translit='Kalviyē ulakai māṟṟakkūṭiya cakti mikka āyutam.',
           sources=[WQ_MANDELA_EN, WQ_MANDELA_TA],
           origin='Nelson Mandela')


add_sample('ta', 'செய்து முடிக்கும் வரை செய்ய முடியாதது போலத்தான் இருக்கும்.',
           script='Taml',
           english='It always seems impossible until it is done.',
           translit='Ceytu muṭikkum varai ceyya muṭiyātatu pōlattāṉ irukkum.',
           sources=[WQ_MANDELA_EN, WQ_MANDELA_TA],
           origin='Nelson Mandela')

add_sample('ta', 'நல்ல தலையும் நல்ல இதயமும் எப்பொழுதும் வல்லமை மிக்க சேர்க்கையாகும்.',
           script='Taml',
           english='A good head and a good heart are always a formidable combination.',
           translit='Nalla talaiyum nalla itayamum eppoḻutum vallamai mikka cērkkaiyākum.',
           sources=[WQ_MANDELA_EN, WQ_MANDELA_TA],
           origin='Nelson Mandela')

WQ_MARIE_CURIE_TE = 'మేరీ క్యూరీ - వికీవ్యాఖ్య, 10:59, 3 జనవరి 2015 <https://te.wikiquote.org/w/index.php?title=%E0%B0%AE%E0%B1%87%E0%B0%B0%E0%B1%80_%E0%B0%95%E0%B1%8D%E0%B0%AF%E0%B1%82%E0%B0%B0%E0%B1%80&oldid=12492>'
WQ_MARIE_CURIE_EN = 'Marie Curie - Wikiquote, 18:30, 24 May 2018 <https://en.wikiquote.org/w/index.php?title=Marie_Curie&oldid=2408899>'
WQ_BERNARD_SHAW_TE = 'జార్జి బెర్నార్డ్ షా - వికీవ్యాఖ్య, 02:40, 22 ఆగస్టు 2015 <https://te.wikiquote.org/w/index.php?title=%E0%B0%9C%E0%B0%BE%E0%B0%B0%E0%B1%8D%E0%B0%9C%E0%B0%BF_%E0%B0%AC%E0%B1%86%E0%B0%B0%E0%B1%8D%E0%B0%A8%E0%B0%BE%E0%B0%B0%E0%B1%8D%E0%B0%A1%E0%B1%8D_%E0%B0%B7%E0%B0%BE&oldid=16130>'
WQ_BERNARD_SHAW_EN = 'George Bernard Shaw - Wikiquote, 21:02, 29 May 2018 <https://en.wikiquote.org/w/index.php?title=George_Bernard_Shaw&oldid=2410951>'

add_sample('te', 'జీవితంలో భయపడాల్సిందేమీ లేదు, అన్నీ అర్థం చేసుకోవాల్సినవే.',
           script='Telu',
           english="Nothing in life is to be feared, it is only to be understood.",
           translit='Jīvitanlō bhayapaḍālsindēmī lēdu, annī arthaṁ cēsukōvālsinavē.',
           sources=[WQ_MARIE_CURIE_TE, WQ_MARIE_CURIE_EN],
           origin='Marie Curie')

add_sample('te', 'నువ్వు భయపడే దానిపై అవగాహన పెంచుకుంటే నీ భయం పోతుంది.',
           script='Telu',
           english="Now is the time to understand more, so that we may fear less. ",
           translit='Nuvvu bhayapaḍē dānipai avagāhana pen̄cukuṇṭē nī bhayaṁ pōtundi.',
           sources=[WQ_MARIE_CURIE_TE, WQ_MARIE_CURIE_EN],
           origin='Marie Curie')

add_sample('te', 'అవకాశాన్ని వదులుకోకు. అది ప్రతిరోజు రాదు.',
           script='Telu',
           english="Never lose a chance: it doesn't come every day.",
           translit='Avakāśānni vadulukōku. Adi pratirōju rādu.',
           sources=[WQ_BERNARD_SHAW_TE, WQ_BERNARD_SHAW_EN],
           origin='George Bernard Shaw')

WP_PEPPERMINT_PS = 'تور ويلني - ویکیپېډیا، وړیا پوهنغونډ, ۰۹:۴۱, ۲۹ ډيسمبر ۲۰۱۵ <https://ps.wikipedia.org/w/index.php?title=%D8%AA%D9%88%D8%B1_%D9%88%D9%8A%D9%84%D9%86%D9%8A&oldid=183925>'

add_sample('ps', 'نوموړی بوټی له درملنې پرته په سينگار، خوړو او څښاک کې د خوند ښه والي لپاره کارول کېږي.',
           script='Arab',
           english='The plant is used for skin care, food, and health.',
           sources=[WP_PEPPERMINT_PS],
           flags=['translation-wrong'])

add_sample('ps', 'گلان يې د نعناعگانو په ډول پورې اړه لري، كېداى شي چې سره، ارغواني او يا سپين وي.',
           script='Arab',
           english='The flowers, which belong to the mints, may be red, purple or white.',
           sources=[WP_PEPPERMINT_PS],
           flags=['translation-wrong'])

add_sample('ps', 'د تور ويلني پاڼې بيضوى ډوله، تېره څوكه او غاښوره (دندانه) لرونكې دي.',
           script='Arab',
           english='Unique dark oval leaves, with an acute apex and coarsely toothed margins.',
           sources=[WP_PEPPERMINT_PS],
           flags=['translation-wrong'])

WP_MAUPASSANT_MT = 'Guy de Maupassant - Wikipedija, 22:48, 15 Mejju 2015 <https://mt.wikipedia.org/w/index.php?title=Guy_de_Maupassant&oldid=243806>'
WP_MAUPASSANT_EN = 'Guy de Maupassant - Wikipedia, 15:16, 28 May 2018 <https://en.wikipedia.org/w/index.php?title=Guy_de_Maupassant&oldid=843347873>'

add_sample('mt', 'F’daż-żmien kiteb ħafna versi u biċċiet qosra.',
           script='Latn',
           english='He devoted his spare time to writing novels and short stories.',
           sources=[WP_MAUPASSANT_MT, WP_MAUPASSANT_EN])

add_sample('mt', 'Bit-talent u s-sens kummerċjali li kellu ma damx ma sar għani.',
           script='Latn',
           english='His talent and practical business sense made him wealthy.',
           sources=[WP_MAUPASSANT_MT, WP_MAUPASSANT_EN])

add_sample('mt', 'Imxi mal-ħolqa biex issibhom.',
           script='Latn',
           english='Click the link to find out.',
           sources=[WP_MAUPASSANT_MT])

WP_TWI = 'Twi - Wikipedia, 02:47, 15 April 2018 <https://en.wikipedia.org/w/index.php?title=Twi&oldid=836488892>'


add_sample('tw', 'Woatwerɛ wo nuabaa mprɛ pii', script='Latn',
           english='You have written your sister many times',
           sources=[WP_TWI])

add_sample('tw', 'ɔtwerɛɛ nkrataa nwɔtwe nnora', script='Latn',
           english='S/he wrote eight letters yesterday',
           sources=[WP_TWI])

add_sample('tw', 'Wobɛtumi akan adeɛ akɔsi apem?', script='Latn',
           english='Can you count up to one thousand?',
           sources=[WP_TWI])


add_sample('yi', 'דער גרעסטער פלוין אין דער וועלט איז אין אנטארקטיקע.',
           script="Hebr",
           english="The largest plains are in Antarctica",
           translit="",
           sources=['פלוין – װיקיפּעדיע, 17:26, 12 סעפטעמבער 2017 <https://yi.wikipedia.org/w/index.php?title=%D7%A4%D7%9C%D7%95%D7%99%D7%9F&oldid=523980>'])

add_sample('yi', 'מען טוט פארבן אים איבער יעדע דריטע יאר כדי ער זאל נישט ווערן פארזשאווערט.',
           script='Hebr',
           english='It is painted every third year to prevent rusting.',
           translit='men tut farbn im iber yede drite yar khdi er zal nisht vern farzhavert.',
           sources='אייפל טורעם – װיקיפּעדיע, 21:24, 28 יאַנואַר 2018 <https://yi.wikipedia.org/w/index.php?title=%D7%90%D7%99%D7%99%D7%A4%D7%9C_%D7%98%D7%95%D7%A8%D7%A2%D7%9D&oldid=528067>')


add_sample('yi', 'די מאַקסוועלס גלייכונגען זײַנען פֿיר גלייכונגען וואָס מאָלן אויס קלאַסישע עלעקטראָדינאַמיק.',
           script='Hebr',
           english="Maxwell's equations are four partial differential equations that form the foundation of classical electromagnetism.",
           translit="di maxvels gleykhungen zaynen fir gleykhungen vos moln aoys klasishe elektrodinamik.",
           sources=['מאקסוועלס גלײכונגען – װיקיפּעדיע 09:27, 19 מערץ 2018 <https://yi.wikipedia.org/w/index.php?title=%D7%9E%D7%90%D7%A7%D7%A1%D7%95%D7%95%D7%A2%D7%9C%D7%A1_%D7%92%D7%9C%D7%B2%D7%9B%D7%95%D7%A0%D7%92%D7%A2%D7%9F&oldid=529668>'])

add_sample('ha', 'Bincike bincike hanya ce tasamu ilimi a wannan zamani da ba kamarta.',
           script="Latn",
           english="Scientific research is the source of the modern-world knowledge.",
           sources=['Ilmi - Wikipedia, 09:51, 26 Maris 2018 <https://ha.wikipedia.org/w/index.php?title=Ilmi&oldid=36041>'])

# Something about a star. Don't know the translation.
add_sample('ln', 'Etandó mpé káti ya mwangó ezalí ya mɔ̌tɔ́ makási.',
           script='Latn',
           sources=['Monzɔ́tɔ mwa mɔ̌tɔ — Wikipedia, 8 mársi 2013 à 15:15 <https://ln.wikipedia.org/w/index.php?title=Monz%C9%94%CC%81t%C9%94_mwa_m%C9%94%CC%8Ct%C9%94&oldid=108854>'])

# Something about a planet. Similar to the above, but I don't know the translation.
add_sample('ln', 'Etandó ya mwangó ezalí malíli, na mɔ̌tɔ tɛ́.',
           script='Latn',
           sources=['Monzɔ́tɔ mwa malíli — Wikipedia, 27 apríli 2015 à 07:58 <https://ln.wikipedia.org/w/index.php?title=Monz%C9%94%CC%81t%C9%94_mwa_mal%C3%ADli&oldid=111799>'])


add_sample('sw', 'Mlima Everest ni mlima mkubwa kabisa duniani.',
           script='Latn',
           english='Mount Everest is the highest mountain in the world.',
           sources=['Everest (mlima) - Wikipedia, kamusi elezo huru, 13:53, 15 Novemba 2017<https://sw.wikipedia.org/w/index.php?title=Everest_%28mlima%29&oldid=1018844>'])

add_sample('sw', 'Maonyesho ya sanaa yasifiwa kote duniani.',
           script='Latn',
           english='International art exhibitions from the whole world are held.',
           sources=['Sankt Peterburg - Wikipedia, kamusi elezo huru, 19:00, 9 Aprili 2016 <https://sw.wikipedia.org/w/index.php?title=Sankt_Peterburg&oldid=971711>'])

add_sample('ms', 'Banyak juga burung yang datang untuk menetas di sini.',
           script='Latn',
           english='Many birds species hatch their eggs there as well.',
           sources=['Delta Danube - Wikipedia Bahasa Melayu, ensiklopedia bebas, 17:30, 28 November 2017 <https://ms.wikipedia.org/w/index.php?title=Delta_Danube&oldid=4238333>'])

add_sample('ms', 'Tiupan angin dari barat laut membawa salji yang sangat lebat.',
           script='Latn',
           english="Northwest wind gusts bring heavy snow storms.",
           sources=['Jepun - Wikipedia Bahasa Melayu, ensiklopedia bebas, 04:39, 26 Mac 2018 <https://ms.wikipedia.org/w/index.php?title=Jepun&oldid=4315958>'])

## Mh, I don't want my font program to talk about intestines. Although if in Malay,
## that's a word like ‘leather’ in English (as I would also not like my program to
## talk about skins), I may be overreading this. Besides, I couldn't confirm that's
## true.
#add_sample('ms', 'Gitar lama selalunya mengguna tali yang dibuat daripada usus.',
#           english='Old classical guitars have straps made out of intestines.', script='Latn',
#           sources=['Gitar klasik - Wikipedia Bahasa Melayu, ensiklopedia bebas, 18:12, 10 April 2015 <https://ms.wikipedia.org/w/index.php?title=Gitar_klasik&oldid=3601456>'])

add_sample('ms', 'Lohong hitam dijangka oleh teori kerelatifan am.',
           script='Latn',
           english='Black holes are predicted by General Relativity.',
           sources=['Lohong hitam - Wikipedia Bahasa Melayu, ensiklopedia bebas, 20:07, 8 Jun 2018 <https://ms.wikipedia.org/w/index.php?title=Lohong_hitam&oldid=4360706>'])

# No translation
add_sample('ch', "Ti todu mangonfotme gi hafa kumekeilek-ña este i kuttura.",
           script='Latn',
           sources=['Kuttura - Wikipedia, 22:17, 23 Matso 2015 <https://ch.wikipedia.org/w/index.php?title=Kuttura&oldid=17980>'])

# No translation
add_sample('ch', "I taotao siha ni ma'estutudia bioloyia manmafa'nana'an bioloyista.",
           script='Latn',
           sources=['Bioloyia - Wikipedia, 19:14, 20 Eneru 2016 <https://ch.wikipedia.org/w/index.php?title=Bioloyia&oldid=19401>'])

add_sample('fj', 'Ko Viti Levu na yanuyanu levu duadua ena vanua kei na matanitu o Viti.',
           script='Latn',
           english='Viti Levu is the largest island in the Republic of Fuji.',
           sources=['Viti Levu - Wikipedia, 23 Okosita 2016 <https://fj.wikipedia.org/w/index.php?title=Viti_Levu&oldid=29831>'])

WP_ANTARTICA_JV = 'Antartika - Wikipedia, 8 Maret 2018 06.12 <https://jv.wikipedia.org/w/index.php?title=Antartika&oldid=1435453>'

add_sample('jv', 'Kéwan ingkang umum kapanggih ing wewengkon punika inggih pinguin.',
           script='Latn',
           english='The most common animal in the region is the penguin.',
           sources=[WP_ANTARTICA_JV])

add_sample('jv', 'Wisata tumuju Antartika limrahipun kanthi pelayaran laut.',
           script='Latn',
           english='Travel to Antartica usually takes place by sea.',
           sources=[WP_ANTARTICA_JV])

add_sample('jv', 'Perlu wektu watara patang dina saperlu mangkat mulih manjat gunung iki.',
           script='Latn',
           english='It takes approximately four days to climb the mountain.',
           sources=['Gunung Semèru - Wikipedia, 22 Oktober 2017 05.35, <https://jv.wikipedia.org/w/index.php?title=Gunung_Sem%C3%A8ru&oldid=1326683>'],
           flags=['translation-wrong'])


# Something about Sea ice.
add_sample('chr', 'ᎠᎺᏉᎯ ᎤᏁᏍᏓᎳ ᎨᏒᎢ ᎪᏢᎯ ᎢᎪᏢᎯ ᎢgᏁᎸᎯ ᏂᏛᎴᏅᏓ ᎠᎺᏉᎯ ᎠᎹ Ꮎ ᎤᏁᏍᏓᎳᏛᎯ.',
           script='Cher',
           translit='A⁠me⁠quo⁠hi⁠ ⁠u⁠ne⁠s⁠da⁠la⁠ ⁠ge⁠sv⁠i⁠ ⁠go⁠tlv⁠hi⁠ ⁠i⁠go⁠tlv⁠hi⁠ ⁠i⁠g⁠ne⁠lv⁠hi⁠ ⁠ni⁠dv⁠le⁠nv⁠da⁠ ⁠a⁠me⁠quo⁠hi⁠ ⁠a⁠ma⁠ ⁠na⁠ ⁠u⁠ne⁠s⁠da⁠la⁠dv⁠hi.',
           sources=['ᎠᎺᏉᎯ ᎤᏁᏍᏓᎳ - Wikipedia, 02:23, 21 ᎠᎾᎠᎬᏘ 2018 <https://chr.wikipedia.org/w/index.php?title=%E1%8E%A0%E1%8E%BA%E1%8F%89%E1%8E%AF_%E1%8E%A4%E1%8F%81%E1%8F%8D%E1%8F%93%E1%8E%B3&oldid=42718>'])

# Something about Plasma.
add_sample('chr', 'ᎭᏫᎾᏗᏢ ᎢᏳᏍᏗ ᏯᏛᎿ ᎠᎴ ᎠᏑᏰᏗ ᏧᏓᎴᎲᏓ ᏅᏬᏘ, ᎠᏣᏅᏙ ᎨᏒᎢ ᎢᏯᏛᏁᎵᏓᏍᏗ.',
           translit='Ha⁠wi⁠na⁠di⁠tlv⁠ ⁠i⁠yu⁠s⁠di⁠ ⁠ya⁠dv⁠hna⁠ ⁠a⁠le⁠ ⁠a⁠su⁠ye⁠di⁠ ⁠tsu⁠da⁠le⁠hv⁠da⁠ ⁠nv⁠wo⁠ti⁠,⁠ ⁠a⁠tsa⁠nv⁠do⁠ ⁠ge⁠sv⁠i⁠ ⁠i⁠ya⁠dv⁠ne⁠li⁠da⁠s⁠di',
           script='Cher',
           sources=['ᎠᏣᏅᏙ - Wikipedia, 12:41, 20 ᎧᏩᏂ 2018 <https://chr.wikipedia.org/w/index.php?title=%E1%8E%A0%E1%8F%A3%E1%8F%85%E1%8F%99&oldid=41857>'])

# Something about Geometry.
add_sample('chr', 'ᏗᏎᏍᏗ ᏓᏍᏓᏅᏅ ᏚᎴᏅ ᏥᏄᏍᏗ ᎯᎠ ᏠᎨᏏ ᎥᎦᏔᎲᎢ ᎠᏂᎾᏕᎬ ᎬᏙᏗ.',
           translit='Di⁠se⁠s⁠di⁠ ⁠da⁠s⁠da⁠nv⁠nv⁠ ⁠du⁠le⁠nv⁠ ⁠tsi⁠nu⁠s⁠di⁠ ⁠hi⁠a⁠ ⁠tlo⁠ge⁠si⁠ ⁠v⁠ga⁠ta⁠hv⁠i⁠ ⁠a⁠ni⁠na⁠de⁠gv⁠ ⁠gv⁠do⁠di⁠.',
           script='Cher',
           sources=['ᏗᏎᏍᏗ ᏓᏍᏓᏅᏅ - Wikipedia, 12:50, 20 ᎧᏩᏂ 2018 <https://chr.wikipedia.org/w/index.php?title=%E1%8F%97%E1%8F%8E%E1%8F%8D%E1%8F%97_%E1%8F%93%E1%8F%8D%E1%8F%93%E1%8F%85%E1%8F%85&oldid=42422>'])


WP_FRANKLIN_VI = 'Benjamin Franklin, Wikiquote, 22:49, ngày 28 tháng 8 năm 2017 <https://vi.wikiquote.org/w/index.php?title=Benjamin_Franklin&oldid=39394>'

add_sample('vi', 'Nếu bạn có việc gì cho ngày mai, làm hôm nay đi.',
           english='If you have something to do tomorrow, do it today.',
           script='Latn',
           sources=[WP_FRANKLIN_VI])

add_sample('vi', 'Cái bánh xe tệ nhất tạo nên tiếng ồn to nhất.',
           english='The worst wheel of the cart makes the most noise.',
           script='Latn',
           sources=[WP_FRANKLIN_VI])


add_sample('vi', 'Nói với tôi và tôi quên. Dạy cho tôi và tôi nhớ. Thu hút tôi và tôi học.',
           english='Tell me and I forget. Teach me and I remember. Involve me and I learn.',
           script='Latn',
           sources=[WP_FRANKLIN_VI])

WP_SIEM_REAP_KM = 'ខេត្តសៀមរាប - វិគីភីឌា, ទី៣០ ខែឧសភា ឆ្នាំ២០១៨ ដោយ <https://km.wikipedia.org/w/index.php?title=%E1%9E%81%E1%9F%81%E1%9E%8F%E1%9F%92%E1%9E%8F%E1%9E%9F%E1%9F%80%E1%9E%98%E1%9E%9A%E1%9E%B6%E1%9E%94&oldid=212135>'

# FIXME: I'm not sure if the sentence is proper, since I cut it off.
add_sample('km', 'ខេត្តនេះជាតំបន់ទេសចរណ៍ដ៍សំខាន់របស់ប្រទេសកម្ពុជា ។',
           translit='khett nih chea tambn tesachar saamkhan robsa bratesa kampouchea .',
           english='The province is one of the major tourist destinations in Cambodia',
           script='Khmr',
           sources=[WP_SIEM_REAP_KM])

add_sample('km', 'បើ​តាម​ដឹង ស្រះ​នេះ​​គឺ​ជា​កន្លែង​សំរាប់​ព្រះ​រាជា​ស្រង់​ទឹក។',
           translit='bae​ tam doeng sreah​ nih​​ ku​ chea​ kanleng​ saamreab​ preah​ reachea​ srang​ tuk .',
           english='The minister built the reservoir for himself',
           script='Khmr',
           sources=[WP_SIEM_REAP_KM],
           flags=['translation-wrong'])

WP_BIOLOGY_KM = 'ជីវវិទ្យា - វិគីភីឌា, ទី០៣ ខែមេសា ឆ្នាំ២០១៨ <https://km.wikipedia.org/w/index.php?title=%E1%9E%87%E1%9E%B8%E1%9E%9C%E1%9E%9C%E1%9E%B7%E1%9E%91%E1%9F%92%E1%9E%99%E1%9E%B6&oldid=210655>'


add_sample('km', 'អណូជីវវិទ្យា គឺជាការសិក្សាអំពីជីវវិទ្យានៅកម្រិតអណូ ។',
           english='Molecular biology studies organisms at the molecular level.',
           translit='chivvityea kuchea karseksaea ampi chivvityea now kamrit anau .',
           script='Khmr',
           sources=[WP_BIOLOGY_KM])

add_sample('km', 'ការវិវត្តខាងអតិសុខុមទស្សន៍វិជ្ជា ក៏មានឥទ្ធិពលយ៉ាងជ្រៅលើគំនិតជីវសាស្ត្រខ្លួនឯងផងដែរ ។',
           english='The invention of the microscope had a large impact on the study of biology.',
           translit='kar vivott khang atesokhom tossaa vichchea ka mean itthipl yeang chrow leu koumnit chivsastr khluoneng phng der .',
           script='Khmr',
           sources=[WP_BIOLOGY_KM])

WP_THAILAND_LO = 'ປະເທດໄທ - ວິກິພີເດຍ, ໑໓:໕໒, ໑໖ ທັນວາ ໒໐໑໗ <https://lo.wikipedia.org/w/index.php?title=%E0%BA%9B%E0%BA%B0%E0%BB%80%E0%BA%97%E0%BA%94%E0%BB%84%E0%BA%97&oldid=64322>'

add_sample('lo', 'ລະດູຮ້ອນເລິ່ມຕັ້ງແຕ່ເດືອນພຶດສະພາຮອດເດືອນກັນຍາ',
           english='The summer takes place from May to September',
           translit='laduhon loem tangaet deuon phudsapha hod deuonknaia',
           script='Laoo', sources=[WP_THAILAND_LO])


add_sample('lo', 'ສ່ວນໃຫຍ່ມາທ່ອງທ່ຽວຕາມຊາຍຫາດແລະພັກຜ່ອນ',
           english='People visit the seashore for relaxation',
           translit='suanhainy ma thongthiav tam sai had lae phakphon',
           script='Laoo', sources=[WP_THAILAND_LO])

add_sample('lo', 'ບັດດຽວນີ້ມະຫາວິທະຍາໄລມີຫຼັກສູດຄອບຄຸມເກືອບທຸກສາຂາວິຊາ',
           english="Nowadays, the university's curriculum has expanded to cover almost any subject",
           translit='bad diauani mahavithanyalai mi raksud khob khum keuob thuk sakhavisa',
           script='Laoo', sources=[WP_THAILAND_LO])


WP_COLD_FRONT_MN = 'Агаарын фронт — Википедиа нэвтэрхий толь, 17:40, 11 Наймдугаар сар 2014-ий <https://mn.wikipedia.org/w/index.php?title=%D0%90%D0%B3%D0%B0%D0%B0%D1%80%D1%8B%D0%BD_%D1%84%D1%80%D0%BE%D0%BD%D1%82&oldid=401772>'

add_sample('mn', 'Хүйтэн агаар дулаан агаар луу шилжиж буй үед үүснэ.',
           translit='Khuiten agaar dulaan agaar luu shiljij bui uyed uusne.',
           english='Cold air appears when the warm air is updrafted',
           sources=[WP_COLD_FRONT_MN], script='Cyrl', flags=['translation-wrong'])

add_sample('mn', 'Энэ үед заримдаа өндрийн бөөн үүл үүснэ.',
           translit='Ene uyed zarimdaa ondriin boon uul uusne.',
           english='During that time, sometimes high-altitude clouds appear',
           sources=[WP_COLD_FRONT_MN], script='Cyrl', flags=['translation-wrong'])

add_sample('mn', 'Нягтрал гэдэг нь пикселээр илэрхийлсэн хөндлөн ба босоо хэмжээ юм.',
           english='Resolution is two-dimensional quantity expressed in vertical and horizontal amount of pixels',
           translit='Nyagtral gedeg ni piksyeleer ilerkhiilsen khondlon ba bosoo khemjee yum.',
           sources=['Шингэн кристалан дэлгэц — Википедиа нэвтэрхий толь, 10:25, 18 Наймдугаар сар 2015-ий <https://mn.wikipedia.org/w/index.php?title=%D0%A8%D0%B8%D0%BD%D0%B3%D1%8D%D0%BD_%D0%BA%D1%80%D0%B8%D1%81%D1%82%D0%B0%D0%BB%D0%B0%D0%BD_%D0%B4%D1%8D%D0%BB%D0%B3%D1%8D%D1%86&oldid=442940>'],
           script='Cyrl')

use_display_scripts('mn-cn', ['Mong'])


WP_VALLEY_NE = 'नेपालका उपत्यकाहरू - विकिपिडिया ०६:४२, ७ जुन २०१८को <https://ne.wikipedia.org/w/index.php?title=%E0%A4%A8%E0%A5%87%E0%A4%AA%E0%A4%BE%E0%A4%B2%E0%A4%95%E0%A4%BE_%E0%A4%89%E0%A4%AA%E0%A4%A4%E0%A5%8D%E0%A4%AF%E0%A4%95%E0%A4%BE%E0%A4%B9%E0%A4%B0%E0%A5%82&oldid=643215>'

add_sample('ne', 'फेवा तालमा पर्ने माछापुच्छ्रे हिमालको छायाँ तथा बेगनासमा गरिने डुङगा सवारी अत्यन्तै मनमोहक छन् ।',
           english='The reflection of Mount Macchapucchre in the lakes is very beautiful.',
           translit='Phēvā tālamā parnē māchāpucchrē himālakō chāyām̐ tathā bēganāsamā garinē ḍuṅagā savārī atyantai manamōhaka chan.',
           flags=['translation-wrong'],
           script='Deva', sources=[WP_VALLEY_NE])

add_sample('ne', 'यो पहाडी क्षेत्रको सबैभन्दा ठूलो उपत्यका हो ।',
           english='It is the largest valley in the mountains.',
           translit='Yō pahāḍī kṣētrakō sabaibhandā ṭhūlō upatyakā hō.',
           script='Deva', sources=[WP_VALLEY_NE])


add_sample('ne', 'यो प्युठान जिल्लाको सबैभन्दा ठूलो बजारहरू मध्ये एक पनि हो ।',
           english='It is one of the biggest markets in Pyuthan District.',
           translit='Yō pyuṭhāna jillākō sabaibhandā ṭhūlō bajāraharū madhyē ēka pani hō.',
           script='Deva', sources=[WP_VALLEY_NE])

# The reindeer is...
add_sample('iu', 'ᑐᒃᑐ ᐱᕈᖅᓯᐊᖅ ᑐᖑᖅᑐᖅ ᑲᑲᒍᑎᖃᖅᖢᓂ ᓯᓕᐅᔭᖅᖢᓂ ᑐᒃᑑᖕᒥᔪᖅ.',
           translit='Tuktu piruqsiaq tunguqtuq kakagutiqaqluni siliujaqluni tuktuungmijuq.',
           script='Cans',
           sources=['ᑐᒃᑐ - ᐅᐃᑭᐱᑎᐊ, 09:50, 28 ᑎᓯᒻᐳᕆ 2015 <https://iu.wikipedia.org/w/index.php?title=%E1%91%90%E1%92%83%E1%91%90&oldid=41369>'])

# The eye is...
add_sample('iu', 'ᐃᔨ ᐊᑕᓐᓂᐅᐹ ᓯᓚᕐᔪᐊᒥᐅᑦ ᐃᓗᖅᐳᖅ ᓯᓚᕐᔪᐊᒥᐅᑦ ᐱᑦᓴᑎᑦᑐᖅ ᐅᕝᕙ.',
           translit='Iji atanniupaa silarjuamiut iluqpuq silarjuamiut pitsatittuq uvva.',
           script='Cans',
           sources=['ᐃᔨ - ᐅᐃᑭᐱᑎᐊ, 17:03, 7 ᒫᕐᓯ 2013 <https://iu.wikipedia.org/w/index.php?title=%E1%90%83%E1%94%A8&oldid=39206>'])

# Clothing is...
add_sample('iu', 'ᐊᐅᑦᓯᓇᖅᑐᖅ ᓱᓕᐊᖅ ᐊᓂᖅᐸᓈᖅᑑᔭᖅᑐᖅ ᐅᓚᐱᑉᐹ ᓴᐳᒻᒥᕚ ᑎᒥ.',
           translit='Autsinaqtuq suliaq aniqpanaaqtuujaqtuq ulapippaa sapummivaa timi.',
           script='Cans',
           sources=['ᐊᐅᑦᓯᓇᖅᑐᖅ - ᐅᐃᑭᐱᑎᐊ, 18:45, 15 ᒪᐃ 2017 <https://iu.wikipedia.org/w/index.php?title=%E1%90%8A%E1%90%85%E1%91%A6%E1%93%AF%E1%93%87%E1%96%85%E1%91%90%E1%96%85&oldid=41831>'])

add_sample('bi', 'Astronomi i stadi blong plante kaen samting blong skae.',
           english='Astronomy is a study of the planets in the sky.',
           script='Latn',
           sources=['Astronomi - Wikipedia, 17:12, 18 Februari 2017 <https://bi.wikipedia.org/w/index.php?title=Astronomi&oldid=35383>'],
           flags=['translation-wrong'])

add_sample('bi', 'Medisin em i saens mo at blong ol badi blong ol pipol mo ol animol.',
           english='Medicine is a science that studied the bodies of people and animals.',
           script='Latn',
           sources=['Medisin - Wikipedia, 14:20, 4 Februari 2017 <https://bi.wikipedia.org/w/index.php?title=Medisin&oldid=35330>'],
           flags=['translation-wrong'])

# Astronomy...
add_sample('haw', 'Kilo kēia akeakamai i nā hōkū, nā hōkūhele, nā hōkū puhipaka, a me nā wiliau hōkū.',
           script='Latn',
           sources=['Kilo hōkū - Wikipedia, 12:06, 22 Kepakemapa 2014 <https://haw.wikipedia.org/w/index.php?title=Kilo_h%C5%8Dk%C5%AB&oldid=70870>'])

# The art of dancing is movement of the body?
add_sample('haw', 'He pāheona ka hulahula o ka neʻena o ke kino.',
           script='Latn',
           sources=['Hulahula - Wikipedia, 17:41, 11 Nowemapa 2016 <https://haw.wikipedia.org/w/index.php?title=Hulahula&oldid=72456>'])

# Physics is...
add_sample('haw', 'He akeakamai ke kālaikūlohea i nā meakino a me ka ʻoni o nā meakino.',
           script='Latn',
           sources=['Kālaikūlohea - Wikipedia, 12:53, 22 Kepakemapa 2014 <https://haw.wikipedia.org/w/index.php?title=K%C4%81laik%C5%ABlohea&oldid=70876>'])

# The pinyon jay eats pine nuts ???
add_sample('nv', 'Tsʼání éí neeshchʼííʼ yideeł łeh; łahda tsin bineestʼąʼ dóó dzidzé yildeeł ałdóʼ.',
           script='Latn',
           sources=['Tsʼání - Wikiibíídiiya, 14 Tʼą́ą́tsoh 2018 <https://nv.wikipedia.org/w/index.php?title=Ts%CA%BC%C3%A1n%C3%AD&oldid=197359>'])


# Phasmatodea are...
add_sample('nv', 'Wónikǫsí éí nahasdzáán bikáaʼgi táaʼdi dimíílgo daatsʼí anééhląąʼ ałʼąą átʼé.',
           script='Latn',
           sources=['Wónikǫsí - Wikiibíídiiya, 00:38, 14 Tʼą́ą́tsoh 2018 <https://nv.wikipedia.org/w/index.php?title=W%C3%B3nik%C7%ABs%C3%AD&oldid=197169>'])

# The bear...
add_sample('nv', 'Shash éí jį́įgo dóó hííłchʼįʼgo naakai; tłʼéeʼgo éí daʼałhosh łeh.',
           script='Latn',
           sources=['Shash - Wikiibíídiiya, 05:12, 6 Atsá Biyáázh 2018 <https://nv.wikipedia.org/w/index.php?title=Shash&oldid=187622>'])


# Thermal physics.
add_sample('bo', 'ཚ་བ་རིག་པ་ནི་ཚ་བའི་བྱུང་བ་དང་བརྒྱུད་སྤྲོད་ལ་ཞིབ་འཇུག་དང་། ཚ་བའི་རྣམ་པའི་འོག་གི་དངོས་པོའི་རང་བཞིན་དང་དེའི་འགྱུར་ལྡོག་ལ་ཞིབ་འཇུག་བྱེད་པའི་རིག་ཚན་ཞིག་ཡིན།',
           script='Tibt',
           sources=['ཚ་བ་རིག་པ་ - Wikipedia, ༡༧:༤༦, ༢༤ ཟླ་བཅུ་གཅིག་པ། ༢༠༡༣ <https://bo.wikipedia.org/w/index.php?title=%E0%BD%9A%E0%BC%8B%E0%BD%96%E0%BC%8B%E0%BD%A2%E0%BD%B2%E0%BD%82%E0%BC%8B%E0%BD%94%E0%BC%8B&oldid=126203>'])


# FIXME: I have absolutely no idea what this sentence means, but it
# is about a species of plant inhabiting Kass Valley of Flowers
# (Elaeocarpus glandulosus), or at least follows one.
add_sample('or', 'ଅଧିତ୍ୟକାଟି ଅଗଷ୍ଟ ଓ ସେପ୍ଟେମ୍ୱର ମାସରେ ବଣୁଆ ଫୁଲରେ ଭରିଯାଏ।',
           script='Orya',
           sources=['କାସ ଅଧିତ୍ୟକା - ଉଇକିପିଡ଼ିଆ, ୨୦:୪୦, ୨୭ ସେପ୍ଟେମ୍ବର ୨୦୧୩ <https://or.wikipedia.org/w/index.php?title=%E0%AC%95%E0%AC%BE%E0%AC%B8_%E0%AC%85%E0%AC%A7%E0%AC%BF%E0%AC%A4%E0%AD%8D%E0%AD%9F%E0%AC%95%E0%AC%BE&oldid=134034>'])

# Murabba is ... ?
add_sample('or', 'ଆମ୍ବ ମୁରବା ଭାରତର ଓଡ଼ିଶାରେ ତିଆରି କରା ଯାଉଥିବା ଏକ ଖାଦ୍ୟ ।',
           script='Orya',
           sources=['ଆମ୍ବ ମୁରବା - ଉଇକିପିଡ଼ିଆ, ୨୧:୫୧, ୪ ଫେବୃଆରୀ ୨୦୧୫ <https://or.wikipedia.org/w/index.php?title=%E0%AC%86%E0%AC%AE%E0%AD%8D%E0%AC%AC_%E0%AC%AE%E0%AD%81%E0%AC%B0%E0%AC%AC%E0%AC%BE&oldid=193061>'])

# Zoology is ... ?
add_sample('or', 'ଜୀବ ବିଜ୍ଞାନର ଅନ୍ୟ ଅର୍ଦ୍ଧେକ ଅଂଶ ହେଉଛି ପ୍ରାଣୀମାନଙ୍କ ଉପରେ ଆଧାରିତ ପ୍ରାଣୀ ବିଜ୍ଞାନ।',
           script='Orya',
           sources=['ବିଜ୍ଞାନ - ଉଇକିପିଡ଼ିଆ, ୦୦:୩୭, ୨୩ ଅକ୍ଟୋବର ୨୦୧୭ <https://or.wikipedia.org/w/index.php?title=%E0%AC%AC%E0%AC%BF%E0%AC%9C%E0%AD%8D%E0%AC%9E%E0%AC%BE%E0%AC%A8&oldid=294714>'])

